@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -34,8 +34,8 @@ class build_suite implements pts_option_interface
 		$suite_maintainer = pts_user_io::prompt_user_input('Enter suite maintainer name');
 		$suite_description = pts_user_io::prompt_user_input('Enter suite description');
 
-		$possible_suites = pts_openbenchmarking_client::available_suites();
-		$possible_tests = pts_openbenchmarking_client::available_tests();
+		$possible_suites = pts_openbenchmarking::available_suites();
+		$possible_tests = pts_openbenchmarking::available_tests();
 
 		$suite_writer = new pts_test_suite_writer();
 		$suite_writer->add_suite_information($suite_name, '1.0.0', $suite_maintainer, $suite_test_type, $suite_description);
