@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2011, Phoronix Media
-	Copyright (C) 2010 - 2011, Michael Larabel
+	Copyright (C) 2010 - 2013, Phoronix Media
+	Copyright (C) 2010 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ class copy_run_in_result_file implements pts_option_interface
 
 		$extract_result = pts_merge::merge_test_results_array($merge_selects);
 		pts_client::save_test_result($r[0] . '/composite.xml', $extract_result);
-		pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $r[0] . '/composite.xml');
+		pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $r[0] . '/index.html');
 	}
 }
 
