@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -27,14 +27,9 @@ class diagnostics implements pts_option_interface
 
 	public static function run($r)
 	{
-		$pts_defined_constants = get_defined_constants(true);
-		$show_all_constants = isset($r[0]) && $r[0] == 'full';
-		foreach($pts_defined_constants['user'] as $constant => $constant_value)
+		foreach(pts_define(-1) as $constant => $constant_value)
 		{
-			if($show_all_constants || (substr($constant, 0, 3) != 'IS_' && substr($constant, 0, 5) != 'TYPE_'))
-			{
-				echo $constant . ' = ' . $constant_value . PHP_EOL;
-			}
+			echo $constant . ' = ' . $constant_value . PHP_EOL;
 		}
 
 		echo PHP_EOL . 'Variables That Can Be Used As Result Identifiers / File Names:' . PHP_EOL;
