@@ -23,7 +23,7 @@
 class reorder_result_file implements pts_option_interface
 {
 	const doc_section = 'Result Management';
-	const doc_description = 'This option is used if you wish to change the order in which test results are shown in the Phoronix Test Suite Results Viewer and the contained graphs. The user must specify a saved results file and then they will be prompted to select the results identifiers one at a time in the order they would like them to be displayed from left to right.';
+	const doc_description = 'This option is used if you wish to manually change the order in which test results are shown in the Phoronix Test Suite Results Viewer and the contained graphs. The user must specify a saved results file and then they will be prompted to select the results identifiers one at a time in the order they would like them to be displayed from left to right.';
 
 	public static function argument_checks()
 	{
@@ -69,6 +69,10 @@ class reorder_result_file implements pts_option_interface
 		pts_client::save_test_result($args[0] . '/composite.xml', $ordered_result);
 		pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $args[0] . '/index.html');
 	}
+	public static function invalid_command($passed_args = null)
+	{
+		pts_tests::recently_saved_results();
+	}
 }
 
 ?>
