@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2013, Phoronix Media
-	Copyright (C) 2009 - 2013, Michael Larabel
+	Copyright (C) 2009 - 2014, Phoronix Media
+	Copyright (C) 2009 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,22 +23,23 @@
 class phoromatic extends pts_module_interface
 {
 	const module_name = 'Phoromatic Client';
-	const module_version = '2.0.0';
-	const module_description = 'The Phoromatic client is used for connecting to a Phoromatic server (Phoromatic.com or a locally run server) to facilitate the automatic running of tests, generally across multiple test nodes in a routine manner. For more details visit http://www.phoromatic.com/';
+	const module_version = '0.1.0';
+	const module_description = 'The Phoromatic client is used for connecting to a Phoromatic server (Phoromatic.com or a locally run server) to facilitate the automatic running of tests, generally across multiple test nodes in a routine manner. For more details visit http://www.phoromatic.com/. This module is intended to be used with Phoronix Test Suite 5.2+ clients and servers.';
 	const module_author = 'Phoronix Media';
 
-	static $phoromatic_server_build = false;
-
-	static $phoromatic_host = null;
-	static $phoromatic_account = null;
-	static $phoromatic_verifier = null;
-	static $phoromatic_system = null;
-	static $openbenchmarking_upload_json = null;
+	static $account_id = null;
+	static $server_address = null;
+	static $server_http_port = null;
+	static $server_ws_port = null;
 
 	public static function module_info()
 	{
 		return 'The Phoromatic module contains the client support for interacting with Phoromatic and Phoromatic Tracker services. A public, free reference implementation of Phoromatic can be found at http://www.phoromatic.com/. A commercial version is available to enterprise customers for installation onto their intranet. For more information, contact Phoronix Media.';
 	}
+	public static function user_commands()
+	{
+		return array('connect' => 'run_connection');
+	}
 	public static function module_setup()
 	{
 		return array(
@@ -48,6 +49,267 @@ class phoromatic extends pts_module_interface
 		new pts_module_option('system_description', 'Enter a short (optional) description for this system', null, null, null, false)
 		);
 	}
+	protected static function upload_to_remote_server($to_post, $server_address = null, $server_http_port = null, $account_id = null)
+	{
+		static $last_communication_minute = null;
+		static $communication_attempts = 0;
+
+		if($last_communication_minute == date('i') && $communication_attempts > 3)
+		{
+				// Something is wrong, Phoromatic shouldn't be communicating with server more than four times a minute
+				return false;
+		}
+		else
+		{
+			if(date('i') != $last_communication_minute)
+			{
+				$last_communication_minute = date('i');
+				$communication_attempts = 0;
+			}
+
+			$communication_attempts++;
+		}
+
+		if($server_address == null && self::$server_address != null)
+		{
+			$server_address = self::$server_address;
+		}
+		if($server_http_port == null && self::$server_http_port != null)
+		{
+			$server_http_port = self::$server_http_port;
+		}
+		if($account_id == null && self::$account_id != null)
+		{
+			$account_id = self::$account_id;
+		}
+
+		$to_post['aid'] = $account_id;
+		$to_post['pts'] = PTS_VERSION;
+		$to_post['pts_core'] = PTS_CORE_VERSION;
+		$to_post['gsid'] = PTS_GSID;
+		$to_post['lip'] = pts_network::get_local_ip();
+		$to_post['h'] = phodevi::system_hardware(true);
+		$to_post['s'] = phodevi::system_software(true);
+		$to_post['n'] = phodevi::read_property('system', 'hostname');
+		return pts_network::http_upload_via_post('http://' . $server_address . ':' . $server_http_port .  '/phoromatic.php', $to_post);
+	}
+	protected static function update_system_status($current_task, $estimated_time_remaining = 0)
+	{
+		return $server_response = phoromatic::upload_to_remote_server(array(
+				'r' => 'update_system_status',
+				'a' => $current_task,
+				'time' => $estimated_time_remaining
+				));
+	}
+	public static function run_connection($args)
+	{
+		if(pts_client::create_lock(PTS_USER_PATH . 'phoromatic_lock') == false)
+		{
+			trigger_error('Phoromatic is already running.', E_USER_ERROR);
+			return false;
+		}
+
+		self::$account_id = substr($args[0], strrpos($args[0], '/') + 1);
+		self::$server_address = substr($args[0], 0, strpos($args[0], ':'));
+		self::$server_http_port = substr($args[0], strlen(self::$server_address) + 1, -1 - strlen(self::$account_id));
+		pts_client::$display->generic_heading('Server IP: ' . self::$server_address . PHP_EOL . 'Server HTTP Port: ' . self::$server_http_port . PHP_EOL . 'Account ID: ' . self::$account_id);
+		$times_failed = 0;
+
+		while(1)
+		{
+			$server_response = phoromatic::upload_to_remote_server(array(
+				'r' => 'start',
+				));
+
+			if($server_response == false)
+			{
+				$times_failed++;
+
+				if($times_failed > 2)
+				{
+					trigger_error('Communication with server failed.', E_USER_ERROR);
+					return false;
+				}
+			}
+			else if(substr($server_response, 0, 1) == '{')
+			{
+				$times_failed = 0;
+				$json = json_decode($server_response, true);
+
+				if($json != null)
+				{
+					if(isset($json['phoromatic']['error']) && !empty($json['phoromatic']['error']))
+					{
+						trigger_error($json['phoromatic']['error'], E_USER_ERROR);
+					}
+					if(isset($json['phoromatic']['response']) && !empty($json['phoromatic']['response']))
+					{
+						echo PHP_EOL . $json['phoromatic']['response'] . PHP_EOL;
+					}
+				}
+
+				switch(isset($json['phoromatic']['task']) ? $json['phoromatic']['task'] : null)
+				{
+					case 'benchmark':
+						$test_flags = pts_c::auto_mode | pts_c::batch_mode;
+						$suite_identifier = sha1(time() . rand(0, 100));
+						pts_suite_nye_XmlReader::set_temporary_suite($suite_identifier, $json['phoromatic']['test_suite']);
+
+						$phoromatic_schedule_id = $json['phoromatic']['trigger_id'];
+						$phoromatic_results_identifier = $phoromatic_schedule_id;
+						$phoromatic_save_identifier = $json['phoromatic']['save_identifier'];
+						$phoromatic_trigger = $phoromatic_schedule_id;
+						phoromatic::update_system_status('Running Benchmarks For Schedule: ' . $phoromatic_save_identifier . ' - ' . $phoromatic_schedule_id);
+
+						if($json['phoromatic']['settings']['RunInstallCommand'])
+						{
+							phoromatic::set_user_context($json['phoromatic']['pre_install_set_context'], $phoromatic_trigger, $phoromatic_schedule_id, 'PRE_INSTALL');
+
+							if($json['phoromatic']['settings']['ForceInstallTests'])
+							{
+								$test_flags |= pts_c::force_install;
+							}
+
+							pts_client::set_test_flags($test_flags);
+							pts_test_installer::standard_install($suite_identifier);
+							phoromatic::set_user_context($json['phoromatic']['post_install_set_context'], $phoromatic_trigger, $phoromatic_schedule_id, 'POST_INSTALL');
+						}
+
+						// Do the actual running
+						if(pts_test_run_manager::initial_checks($suite_identifier))
+						{
+							$test_run_manager = new pts_test_run_manager($test_flags);
+							pts_test_run_manager::set_batch_mode(array(
+								'UploadResults' => true,
+								'SaveResults' => true,
+								'RunAllTestCombinations' => false,
+								'OpenBrowser' => false
+								));
+
+							// Load the tests to run
+							if($test_run_manager->load_tests_to_run($suite_identifier))
+							{
+								phoromatic::set_user_context($json['phoromatic']['pre_run_set_context'], $phoromatic_trigger, $phoromatic_schedule_id, 'PRE_RUN');
+								if(true)
+								{
+									$test_run_manager->auto_upload_to_openbenchmarking();
+									pts_openbenchmarking_client::override_client_setting('UploadSystemLogsByDefault', $json['phoromatic']['settings']['UploadSystemLogs']);
+								}
+
+								// Save results?
+								$test_run_manager->auto_save_results($phoromatic_save_identifier, $phoromatic_results_identifier, 'A Phoromatic run.');
+
+								// Run the actual tests
+								$test_run_manager->pre_execution_process();
+								$test_run_manager->call_test_runs();
+								phoromatic::update_system_status('Benchmarks Completed For Schedule: ' . $phoromatic_save_identifier . ' - ' . $phoromatic_schedule_id);
+								$test_run_manager->post_execution_process();
+
+								// Upload to Phoromatic
+								$ob_data = $test_run_manager->get_result_upload_data();
+
+								$server_response = phoromatic::upload_to_remote_server(array(
+									'r' => 'result_upload',
+									'ob' => $ob_data['id'],
+									'sched' => $json['phoromatic']['schedule_id'],
+									'o' => $phoromatic_save_identifier,
+									'ts' => $json['phoromatic']['trigger_id'],
+									));
+
+								if(!$json['phoromatic']['settings']['ArchiveResultsLocally'])
+								{
+									pts_client::remove_saved_result_file($test_run_manager->get_file_name());
+								}
+							}
+							phoromatic::set_user_context($json['phoromatic']['post_install_set_context'], $phoromatic_trigger, $phoromatic_schedule_id, 'POST_RUN');
+						}
+					break;
+					case 'exit':
+						echo PHP_EOL . 'Phoromatic received a remote command to exit.' . PHP_EOL;
+						phoromatic::update_system_status('Exiting Phoromatic');
+					break;
+				}
+			}
+			phoromatic::update_system_status('Idling, Waiting For Task');
+			sleep(60);
+		}
+		pts_client::release_lock(PTS_USER_PATH . 'phoromatic_lock');
+	}
+	private static function set_user_context($context_script, $trigger, $schedule_id, $process)
+	{
+		if(!empty($context_script))
+		{
+			$context_file = pts_client::create_temporary_file();
+			file_put_contents($context_file, $context_script);
+			chmod($context_file, 0755);
+
+			pts_file_io::mkdir(pts_module::save_dir());
+			$storage_path = pts_module::save_dir() . 'memory.pt2so';
+			$storage_object = pts_storage_object::recover_from_file($storage_path);
+
+			// We check to see if the context was already set but the system rebooted or something in that script
+			if($storage_object == false)
+			{
+				$storage_object = new pts_storage_object(true, true);
+			}
+			else if($storage_object->read_object('last_set_context_trigger') == $trigger && $storage_object->read_object('last_set_context_schedule') == $schedule_id && $storage_object->read_object('last_set_context_process') == $process)
+			{
+				// If the script already ran once for this trigger, don't run it again
+				return false;
+			}
+
+			$storage_object->add_object('last_set_context_trigger', $trigger);
+			$storage_object->add_object('last_set_context_schedule', $schedule_id);
+			$storage_object->add_object('last_set_context_process', $process);
+			$storage_object->save_to_file($storage_path);
+
+			// Run the set context script
+			exec('./' . $context_script . ' ' . $trigger);
+
+			// Just simply return true for now, perhaps check exit code status and do something
+			return true;
+		}
+
+		return false;
+	}
+	public static function __pre_test_install($test_identifier)
+	{
+		static $last_update_time = 0;
+
+		if(time() > ($last_update_time + 600))
+		{
+			phoromatic::update_system_status('Installing Tests');
+			$last_update_time = time();
+		}
+	}
+	public static function __pre_test_run($pts_test_result)
+	{
+		// TODO: need a way to get the estimated time remaining from the test_run_manager so we can pass that back to the update_system_status parameter so server can read it
+		// TODO: report name of test identifier/run i.e. . ' For ' . PHOROMATIC_TITLE
+		phoromatic::update_system_status('Running ' . $pts_test_result->test_profile->get_identifier());
+	}
+	public static function __event_user_error($user_error)
+	{
+		// Report PTS user error warnings to Phoromatic server
+		phoromatic::report_warning_to_phoromatic($user_error->get_error_string());
+	}
+	public static function __event_results_saved($test_run_manager)
+	{
+		/*if(pts_module::read_variable('AUTO_UPLOAD_RESULTS_TO_PHOROMATIC') && pts_module::is_module_setup())
+		{
+			phoromatic::upload_unscheduled_test_results($test_run_manager->get_file_name());
+		}*/
+	}
+
+
+	//
+	// TODO XXX: The code below here is Phoromatic legacy code still needing to be ported to the new interfaces of PTS 5.2 Khanino
+	//
+
+
+
+
+
 	public static function module_setup_validate($options)
 	{
 		if(substr($options['remote_host'], -14) != 'phoromatic.php')
@@ -56,11 +318,10 @@ class phoromatic extends pts_module_interface
 		}
 
 		$server_response = phoromatic::upload_to_remote_server(array(
-			'r' => 'setup',
+			'r' => 'start',
 			'h' => phodevi::system_hardware(true),
 			's' => phodevi::system_software(true),
-			'o' => phodevi::read_property('system', 'hostname'),
-			'sys_desc' => $options['system_description']
+			'n' => phodevi::read_property('system', 'hostname'),
 			),
 			$options['remote_host'], $options['remote_account'], $options['remote_verifier']);
 
@@ -81,181 +342,11 @@ class phoromatic extends pts_module_interface
 
 		return $options;
 	}
-	public static function user_commands()
-	{
-		return array(
-			'start' => 'user_start',
-			'user_system_return' => 'user_system_return',
-			'upload_results' => 'upload_unscheduled_results',
-			'clone_results' => 'clone_results',
-			'system_schedule' => 'system_schedule',
-			'system_schedule_today' => 'system_schedule_today',
-			'send_message' => 'report_message_to_server'
-			);
-	}
 
 	//
 	// User Run Commands
 	//
 
-	public static function user_start()
-	{
-		if(pts_client::create_lock(PTS_USER_PATH . 'phoromatic_lock') == false)
-		{
-			pts_client::$display->generic_error('Phoromatic is already running.');
-			return false;
-		}
-		if(!phoromatic::phoromatic_setup_module())
-		{
-			return false;
-		}
-
-		phoromatic::user_system_process();
-	}
-	public static function upload_unscheduled_results($to_upload)
-	{
-		if(!phoromatic::phoromatic_setup_module())
-		{
-			return false;
-		}
-
-		if(!isset($to_upload[0]) || pts_result_file::is_test_result_file($to_upload[0]) == false)
-		{
-			echo PHP_EOL . 'No test result file was found to upload.' . PHP_EOL;
-			return false;
-		}
-
-		phoromatic::upload_unscheduled_test_results($to_upload[0]);
-	}
-	public static function clone_results($to_clone)
-	{
-		if(!phoromatic::phoromatic_setup_module())
-		{
-			return false;
-		}
-
-		if(!isset($to_clone[0]) || empty($to_clone[0]))
-		{
-			echo PHP_EOL . 'No clone string was provided.' . PHP_EOL;
-			return false;
-		}
-
-		$server_response = phoromatic::upload_to_remote_server(array(
-			'r' => 'clone_test_results',
-			'i' => $to_clone[0]
-			));
-
-		switch(self::read_xml_value($server_response, 'PhoronixTestSuite/Phoromatic/General/Response'))
-		{
-			case 'TRUE':
-				$identifier = 'phoromatic-clone-' . str_replace(array('_', ':'), null, $to_clone[0]);
-				pts_client::save_test_result($identifier . '/composite.xml', $server_response); // TODO: regenerate the XML so that the Phoromatic response bits are not included
-				echo PHP_EOL . 'Result Saved To: ' . PTS_SAVE_RESULTS_PATH . $identifier . '/composite.xml' . PHP_EOL . PHP_EOL;
-				pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $identifier . '/index.html');
-				break;
-			case 'SETTING_DISABLED':
-				echo PHP_EOL . 'You need to enable this support from your Phoromatic account web interface.' . PHP_EOL;
-				break;
-			default:
-			case 'ERROR':
-				echo PHP_EOL . 'An Error Occurred.' . PHP_EOL;
-				break;
-		}
-	}
-	public static function system_schedule()
-	{
-		if(!phoromatic::phoromatic_setup_module())
-		{
-			return false;
-		}
-
-		$server_response = phoromatic::upload_to_remote_server(array(
-			'r' => 'system_schedule'
-			));
-
-		$schedule_xml = new nye_XmlReader($server_response);
-		$schedule_titles = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/Title');
-		$schedule_description = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/Description');
-		$schedule_active_on = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/ActiveOn');
-		$schedule_start_time = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/RunAt');
-
-		if(count($schedule_titles) == 0)
-		{
-			echo PHP_EOL . 'No test schedules for this system were found on the Phoromatic Server.' . PHP_EOL;
-		}
-		else
-		{
-			for($i = 0; $i < count($schedule_titles); $i++)
-			{
-				echo self::phoromatic_schedule_entry_string($schedule_titles[$i], $schedule_description[$i], $schedule_start_time[$i], $schedule_active_on[$i]);
-			}
-		}
-
-		echo PHP_EOL;
-	}
-	public static function system_schedule_today()
-	{
-		if(!phoromatic::phoromatic_setup_module())
-		{
-			return false;
-		}
-
-		$server_response = phoromatic::upload_to_remote_server(array(
-			'r' => 'system_schedule'
-			));
-
-		$schedule_xml = new nye_XmlReader($server_response);
-		$schedule_titles = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/Title');
-		$schedule_description = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/Description');
-		$schedule_active_on = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/ActiveOn');
-		$schedule_start_time = $schedule_xml->getXmlArrayValues('PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/RunAt');
-
-		if(count($schedule_titles) == 0)
-		{
-			echo PHP_EOL . 'No test schedules for this system were found on the Phoromatic Server.' . PHP_EOL;
-		}
-		else
-		{
-			for($i = 0; $i < count($schedule_titles); $i++)
-			{
-				if($schedule_active_on[$i][(date('w'))] != 1)
-				{
-					continue;
-				}
-
-				echo self::phoromatic_schedule_entry_string($schedule_titles[$i], $schedule_description[$i], $schedule_start_time[$i], $schedule_active_on[$i]);
-			}
-		}
-
-		echo PHP_EOL;
-	}
-	public static function send_message_to_server($msg)
-	{
-		if(!phoromatic::phoromatic_setup_module())
-		{
-			return false;
-		}
-
-		if(empty($msg))
-		{
-			echo PHP_EOL . 'Pass the message as the first argument.' . PHP_EOL;
-			return false;
-		}
-
-		if(self::report_warning_to_phoromatic('MESSAGE: ' . implode(' ', $msg)))
-		{
-			echo PHP_EOL . 'Message Sent To Phoromatic Server.' . PHP_EOL;
-		}
-		else
-		{
-			echo PHP_EOL . 'Message Failed To Send.' . PHP_EOL;
-		}
-	}
-
-	//
-	// Core Functions
-	//
-
 	public static function user_system_process()
 	{
 		define('PHOROMATIC_PROCESS', true);
@@ -328,7 +419,7 @@ class phoromatic extends pts_module_interface
 			switch($response)
 			{
 				case 'benchmark':
-					$test_flags = pts_c::auto_mode;
+					$test_flags = pts_c::auto_mode | pts_c::batch_mode;
 
 					do
 					{
@@ -365,6 +456,12 @@ class phoromatic extends pts_module_interface
 					if(pts_test_run_manager::initial_checks($suite_identifier))
 					{
 						$test_run_manager = new pts_test_run_manager($test_flags);
+						pts_test_run_manager::set_batch_mode(array(
+							'UploadResults' => true,
+							'SaveResults' => true,
+							'RunAllTestCombinations' => false,
+							'OpenBrowser' => false
+							));
 
 						// Load the tests to run
 						if($test_run_manager->load_tests_to_run($suite_identifier))
@@ -468,102 +565,15 @@ class phoromatic extends pts_module_interface
 	// Process Functions
 	//
 
-
-	public static function __pre_test_install($test_identifier)
-	{
-		static $last_update_time = 0;
-
-		if(time() > ($last_update_time + 600))
-		{
-			phoromatic::update_system_status('Installing Tests');
-			$last_update_time = time();
-		}
-	}
-	public static function __pre_test_run($pts_test_result)
-	{
-		// TODO: need a way to get the estimated time remaining from the test_run_manager so we can pass that back to the update_system_status parameter so server can read it
-		// TODO: report name of test identifier/run i.e. . ' For ' . PHOROMATIC_TITLE
-		phoromatic::update_system_status('Running ' . $pts_test_result->test_profile->get_identifier());
-	}
-	public static function __event_user_error($user_error)
-	{
-		// Report PTS user error warnings to Phoromatic server
-		phoromatic::report_warning_to_phoromatic($user_error->get_error_string());
-	}
-	public static function __event_results_saved($test_run_manager)
-	{
-		if(pts_module::read_variable('AUTO_UPLOAD_RESULTS_TO_PHOROMATIC') && pts_module::is_module_setup())
-		{
-			phoromatic::upload_unscheduled_test_results($test_run_manager->get_file_name());
-		}
-	}
-	public static function __event_openbenchmarking_upload($json)
-	{
-		self::$openbenchmarking_upload_json = $json;
-	}
-
 	//
 	// Other Functions
 	//
 
 	protected static function read_xml_value($file, $xml_option)
 	{
-	 	$xml_parser = new nye_XmlReader($file);
+		$xml_parser = new nye_XmlReader($file);
 		return $xml_parser->getXMLValue($xml_option);
 	}
-	private static function set_user_context($context_script, $trigger, $schedule_id, $process)
-	{
-		if(!empty($context_script))
-		{
-			if(!is_executable($context_script))
-			{
-				if(($context_script = pts_client::executable_in_path($context_script)) == false || !is_executable($context_script))
-				{
-					return false;
-				}
-			}
-
-			$storage_path = pts_module::save_dir() . 'memory.pt2so';
-			$storage_object = pts_storage_object::recover_from_file($storage_path);
-
-			// We check to see if the context was already set but the system rebooted or something in that script
-			if($storage_object == false)
-			{
-				$storage_object = new pts_storage_object(true, true);
-			}
-			else if($storage_object->read_object('last_set_context_trigger') == $trigger && $storage_object->read_object('last_set_context_schedule') == $schedule_id && $storage_object->read_object('last_set_context_process') == $process)
-			{
-				// If the script already ran once for this trigger, don't run it again
-				return false;
-			}
-
-			$storage_object->add_object('last_set_context_trigger', $trigger);
-			$storage_object->add_object('last_set_context_schedule', $schedule_id);
-			$storage_object->add_object('last_set_context_process', $process);
-			$storage_object->save_to_file($storage_path);
-
-			// Run the set context script
-			exec($context_script . ' ' . $trigger);
-
-			// Just simply return true for now, perhaps check exit code status and do something
-			return true;
-		}
-
-		return false;
-	}
-	protected static function update_system_details()
-	{
-		$server_response = phoromatic::upload_to_remote_server(array('r' => 'update_system_details', 'h' => phodevi::system_hardware(true), 's' => phodevi::system_software(true)));
-		self::$phoromatic_server_build = self::read_xml_value($server_response, 'PhoronixTestSuite/Phoromatic/Server/ServerBuild');
-
-		return self::read_xml_value($server_response, 'PhoronixTestSuite/Phoromatic/General/Response') == 'TRUE';
-	}
-	protected static function update_system_status($current_task, $estimated_time_remaining = 0)
-	{
-		$server_response = phoromatic::upload_to_remote_server(array('r' => 'update_system_status', 'a' => $current_task, 'time' => $estimated_time_remaining));
-
-		return self::read_xml_value($server_response, 'PhoronixTestSuite/Phoromatic/General/Response') == 'TRUE';
-	}
 	protected static function report_warning_to_phoromatic($warning)
 	{
 		$server_response = phoromatic::upload_to_remote_server(array('r' => 'report_pts_warning', 'a' => $warning));
@@ -619,37 +629,6 @@ class phoromatic extends pts_module_interface
 
 		return self::read_xml_value($server_response, 'PhoronixTestSuite/Phoromatic/General/Response') == 'TRUE';
 	}
-	protected static function upload_unscheduled_test_results($save_identifier)
-	{
-		$composite_xml = file_get_contents(PTS_SAVE_RESULTS_PATH . $save_identifier . '/composite.xml');
-
-		$logs = self::capture_test_logs($save_identifier);
-		$server_response = phoromatic::upload_to_remote_server(array(
-			'r' => 'upload_test_results_unscheduled',
-			'c' => $composite_xml,
-			'i' => 0,
-			'ti' => 'Unknown',
-			'sl' => $logs['system-logs'],
-			'tl' => $logs['test-logs']
-			));
-
-		$xml_parser = new nye_XmlReader($server_response);
-
-		switch($xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/Response'))
-		{
-			case 'TRUE':
-				echo PHP_EOL . 'Uploaded To Phoromatic.' . PHP_EOL;
-				break;
-			case 'ERROR':
-				echo PHP_EOL . 'An Error Occurred.' . PHP_EOL;
-				break;
-			case 'SETTING_DISABLED':
-				echo PHP_EOL . 'You need to enable this support from your Phoromatic account web interface.' . PHP_EOL;
-				break;
-		}
-
-		return $xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/Response') == 'TRUE';
-	}
 	protected static function phoromatic_setup_module()
 	{
 		if(!pts_module::is_module_setup())
@@ -673,65 +652,6 @@ class phoromatic extends pts_module_interface
 		pts_module_manager::attach_module($phoromatic);
 		return true;
 	}
-	protected static function phoromatic_schedule_entry_string($title, $description, $start_time, $active_on)
-	{
-		echo PHP_EOL . $title . ':' . PHP_EOL;
-		echo "\t" . $description . PHP_EOL;
-		echo "\t" . 'Runs at ' . $start_time . ' on ' . pts_strings::parse_week_string($active_on) . '.' . PHP_EOL;
-	}
-
-
-	//
-	// Connection
-	// 
-
-	protected static function upload_to_remote_server($to_post, $host = null, $account = null, $verifier = null, $system = null)
-	{
-		static $last_communication_minute = null;
-		static $communication_attempts = 0;
-
-		if($last_communication_minute == date('i') && $communication_attempts > 3)
-		{
-				// Something is wrong, Phoromatic shouldn't be communicating with server more than four times a minute
-				return false;
-		}
-		else
-		{
-			if(date('i') != $last_communication_minute)
-			{
-				$last_communication_minute = date('i');
-				$communication_attempts = 0;
-			}
-
-			$communication_attempts++;
-		}
-
-		if($host != null)
-		{
-			//$host = $host;
-			$to_post['aid'] = $account;
-			$to_post['vid'] = $verifier;
-			$to_post['sid'] = $system;
-		}
-		else if(self::$phoromatic_host != null)
-		{
-			$host = self::$phoromatic_host;
-			$to_post['aid'] = self::$phoromatic_account;
-			$to_post['vid'] = self::$phoromatic_verifier;
-			$to_post['sid'] = self::$phoromatic_system;
-		}
-		else
-		{
-			echo PHP_EOL . 'Phoromatic isn\'t configured. Run: phoronix-test-suite module-setup phoromatic' . PHP_EOL . PHP_EOL;
-			return;
-		}
-
-		$to_post['pts'] = PTS_VERSION;
-		$to_post['pts_core'] = PTS_CORE_VERSION;
-		$to_post['gsid'] = PTS_GSID;
-
-		return pts_network::http_upload_via_post($host, $to_post);
-	}
 }
 
 ?>
