@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2012, Phoronix Media
-	Copyright (C) 2008 - 2012, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 	system_monitor.php: System sensor monitoring module for PTS
 
 	This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+// TODO XXX: Port to new phodevi_sensor_monitor interface
+
 class system_monitor extends pts_module_interface
 {
 	const module_name = 'System Monitor';
@@ -67,16 +69,15 @@ class system_monitor extends pts_module_interface
 
 	public static function __run_manager_setup(&$test_run_manager)
 	{
-		$test_run_manager->force_results_save();
+		//$test_run_manager->force_results_save();
+		$test_run_manager->disable_dynamic_run_count();
 	}
-
 	public static function __pre_run_process(&$test_run_manager)
 	{
 		self::$result_identifier = $test_run_manager->get_results_identifier();
 		self::$individual_monitoring = pts_module::read_variable('MONITOR_INDIVIDUAL') !== '0';
 		self::$to_monitor = array();
 		$to_show = pts_strings::comma_explode(pts_module::read_variable('MONITOR'));
-		$monitor_all = in_array('all', $to_show);
 
 		if(pts_module::read_variable('PERFORMANCE_PER_WATT'))
 		{
@@ -86,6 +87,7 @@ class system_monitor extends pts_module_interface
 			echo PHP_EOL . 'To Provide Performance-Per-Watt Outputs.' . PHP_EOL;
 		}
 
+		$monitor_all = in_array('all', $to_show);
 		foreach(phodevi::supported_sensors() as $sensor)
 		{
 			if($monitor_all || in_array(phodevi::sensor_identifier($sensor), $to_show) || in_array('all.' . $sensor[0], $to_show))
@@ -112,7 +114,7 @@ class system_monitor extends pts_module_interface
 			echo PHP_EOL;
 
 			// Pad some idling sensor results at the start
-			sleep((self::$sensor_monitoring_frequency * 4));
+			sleep((self::$sensor_monitoring_frequency * 8));
 		}
 
 		pts_module::pts_timed_function('pts_monitor_update', self::$sensor_monitoring_frequency);
@@ -159,7 +161,7 @@ class system_monitor extends pts_module_interface
 		self::$test_run_timer = time() - self::$test_run_timer;
 
 		// Let the system return to brief idling..
-		sleep(self::$sensor_monitoring_frequency);
+		sleep(self::$sensor_monitoring_frequency * 8);
 
 		if(pts_module::read_variable('PERFORMANCE_PER_WATT'))
 		{
