@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 	toggle_screensaver.php: A module to toggle the screensaver while tests are running on GNOME
 
 	This program is free software; you can redistribute it and/or modify
@@ -46,10 +46,16 @@ class toggle_screensaver extends pts_module_interface
 	public static function __startup()
 	{
 		$halt_screensaver = pts_module::read_variable('HALT_SCREENSAVER');
-		if(!empty($halt_screensaver) && !pts_strings::string_bool($halt_screensaver))
+		if((!empty($halt_screensaver) && !pts_strings::string_bool($halt_screensaver)) || phodevi::read_property('system', 'display-server') == null)
 		{
 			return pts_module::MODULE_UNLOAD;
 		}
+		if(phodevi::is_macosx())
+		{
+			// Right now there doesn't appear to be a better way to disable OS X screensaver automatically...
+			return pts_module::MODULE_UNLOAD;
+		}
+
 
 		// GNOME Screensaver?
 		if(($gt = pts_client::executable_in_path('gconftool')) != false || ($gt = pts_client::executable_in_path('gconftool-2')) != false)
@@ -91,7 +97,7 @@ class toggle_screensaver extends pts_module_interface
 			}
 		}
 
-		if(pts_client::executable_in_path('gsettings'))
+		if(self::$gnome2_screensaver_halted == false && pts_client::executable_in_path('gsettings'))
 		{
 			// GNOME 3.x Screensaver?
 			$is_gnome3_screensaver_enabled = trim(shell_exec('gsettings get org.gnome.desktop.session idle-delay 2>&1'));
