@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,9 +22,10 @@
 
 class pts_client
 {
-	public static $display;
+	public static $display = false;
 	private static $current_command = null;
 	protected static $lock_pointers = null;
+	private static $forked_pids = array();
 
 	public static function create_lock($lock_file)
 	{
@@ -39,6 +40,7 @@ class pts_client
 	}
 	public static function init()
 	{
+		set_time_limit(0);
 		pts_define_directories(); // Define directories
 
 		if(function_exists('cli_set_process_title'))
@@ -46,13 +48,32 @@ class pts_client
 			cli_set_process_title('Phoronix Test Suite');
 		}
 
-		if(QUICK_START)
+		if(defined('QUICK_START') && QUICK_START)
 		{
 			return true;
 		}
 
-		self::basic_init_process(); // Initalize common / needed PTS start-up work
-		pts_network::client_startup();
+		pts_define('PHP_BIN', pts_client::read_env('PHP_BIN'));
+		pts_define('PTS_INIT_TIME', time());
+
+		if(!defined('PHP_VERSION_ID'))
+		{
+			// PHP_VERSION_ID is only available in PHP 5.2.6 and later
+			$php_version = explode('.', PHP_VERSION);
+			pts_define('PHP_VERSION_ID', ($php_version[0] * 10000 + $php_version[1] * 100 + $php_version[2]));
+		}
+
+		$dir_init = array(PTS_USER_PATH);
+		foreach($dir_init as $dir)
+		{
+			pts_file_io::mkdir($dir);
+		}
+
+		if(PTS_IS_CLIENT)
+		{
+			pts_network::client_startup();
+		}
+
 		self::core_storage_init_process();
 
 		if(!is_file(PTS_TEMP_STORAGE))
@@ -60,16 +81,19 @@ class pts_client
 			self::build_temp_cache();
 		}
 
-		pts_config::init_files();
+		// XXX: technically the config init_files line shouldn't be needed since it should be dynamically called
+		// pts_config::init_files();
 		pts_define('PTS_TEST_INSTALL_DEFAULT_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Installation/EnvironmentDirectory', '~/.phoronix-test-suite/installed-tests/')));
 		pts_define('PTS_SAVE_RESULTS_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Testing/ResultsDirectory', '~/.phoronix-test-suite/test-results/')));
 		self::extended_init_process();
 
 		$openbenchmarking = pts_storage_object::read_from_file(PTS_CORE_STORAGE, 'openbenchmarking');
+		$openbenchmarking_account_settings = pts_storage_object::read_from_file(PTS_CORE_STORAGE, 'openbenchmarking_account_settings');
+
 		if($openbenchmarking != null)
 		{
 			// OpenBenchmarking.org Account
-			pts_openbenchmarking_client::init_account($openbenchmarking);
+			pts_openbenchmarking_client::init_account($openbenchmarking, $openbenchmarking_account_settings);
 		}
 
 		return true;
@@ -153,31 +177,6 @@ class pts_client
 		pts_define('PTS_STARTUP_TASK_PERFORMED', true);
 		register_shutdown_function(array('pts_module_manager', 'module_process'), '__shutdown');
 	}
-	public static function open_basedir_check()
-	{
-		$passes = true;
-		$open_basedir = ini_get('open_basedir');
-
-		if($open_basedir != false)
-		{
-			$is_in_allowed_dir = false;
-			foreach(explode(':', $open_basedir) as $allowed_dir)
-			{
-				if(strpos(PTS_PATH, $allowed_dir) === 0)
-				{
-					$is_in_allowed_dir = true;
-					break;
-				}
-			}
-
-			if($is_in_allowed_dir == false)
-			{
-				$passes = false;
-			}
-		}
-
-		return $passes;
-	}
 	public static function environmental_variables()
 	{
 		// The PTS environmental variables passed during the testing process, etc
@@ -191,6 +190,7 @@ class pts_client
 			'PTS_DIR' => PTS_PATH,
 			'PHP_BIN' => PHP_BIN,
 			'NUM_CPU_CORES' => phodevi::read_property('cpu', 'core-count'),
+			'NUM_CPU_NODES' => phodevi::read_property('cpu', 'node-count'),
 			'NUM_CPU_JOBS' => (phodevi::read_property('cpu', 'core-count') * 2),
 			'SYS_MEMORY' => phodevi::read_property('memory', 'capacity'),
 			'VIDEO_MEMORY' => phodevi::read_property('gpu', 'memory-capacity'),
@@ -428,29 +428,14 @@ class pts_client
 
 		return $real_name;
 	}
-	private static function basic_init_process()
-	{
-		// Initialize The Phoronix Test Suite
-
-		// PTS Defines
-		pts_define('PHP_BIN', pts_client::read_env('PHP_BIN'));
-		pts_define('PTS_INIT_TIME', time());
-
-		if(!defined('PHP_VERSION_ID'))
-		{
-			// PHP_VERSION_ID is only available in PHP 5.2.6 and later
-			$php_version = explode('.', PHP_VERSION);
-			pts_define('PHP_VERSION_ID', ($php_version[0] * 10000 + $php_version[1] * 100 + $php_version[2]));
-		}
-
-		$dir_init = array(PTS_USER_PATH);
-		foreach($dir_init as $dir)
-		{
-			pts_file_io::mkdir($dir);
-		}
-	}
 	public static function init_display_mode($flags = 0)
 	{
+		if(PTS_IS_WEB_CLIENT && !defined('PHOROMATIC_SERVER'))
+		{
+			self::$display = new pts_web_display_mode();
+			return;
+		}
+
 		$env_mode = ($flags & pts_c::debug_mode) ? 'BASIC' : false;
 
 		switch(($env_mode != false || ($env_mode = pts_client::read_env('PTS_DISPLAY_MODE')) != false ? $env_mode : pts_config::read_user_config('PhoronixTestSuite/Options/General/DefaultDisplayMode', 'DEFAULT')))
@@ -600,7 +585,7 @@ class pts_client
 				pts_define('PTS_GSID_E', $global_gsid['gsid_e']);
 			}
 		}
-		else if(pts_openbenchmarking::is_valid_gsid_e_format($global_gsid_e) == false || pts_openbenchmarking::is_valid_gsid_e_format($global_gsid_p) == false)
+		else if(pts_openbenchmarking::is_valid_gsid_e_format($global_gsid_e) == false || pts_openbenchmarking::is_valid_gsid_p_format($global_gsid_p) == false)
 		{
 			pts_define('PTS_GSID', $global_gsid);
 			$requested_gsid = false;
@@ -1062,10 +1047,10 @@ class pts_client
 
 		return $generated_graphs;
 	}
+
 	public static function process_shutdown_tasks()
 	{
 		// TODO: possibly do something like posix_getpid() != pts_client::$startup_pid in case shutdown function is called from a child process
-
 		// Generate Phodevi Smart Cache
 		if(pts_flags::no_phodevi_cache() == false && pts_client::read_env('EXTERNAL_PHODEVI_CACHE') == false)
 		{
@@ -1086,6 +1071,14 @@ class pts_client
 				self::release_lock($lock_file);
 			}
 		}
+
+		foreach(self::$forked_pids as $pid)
+		{
+			if(is_dir('/proc/' . $pid) && function_exists('posix_kill'))
+			{
+				posix_kill($pid, SIGKILL);
+			}
+		}
 	}
 	public static function do_anonymous_usage_reporting()
 	{
@@ -1218,14 +1211,14 @@ class pts_client
 
 					if((isset($pass_args[$argument_check->get_argument_index()]) && !empty($pass_args[$argument_check->get_argument_index()])) || ($argument_check->get_argument_index() == 'VARIABLE_LENGTH' && !empty($pass_args)))
 					{
-						pts_client::$display->generic_error('Invalid Argument: ' . implode(' ', $pass_args));
+						trigger_error('Invalid Argument: ' . implode(' ', $pass_args), E_USER_ERROR);
 					}
 					else
 					{
-						pts_client::$display->generic_error('Argument Missing.');
+						trigger_error('Phoronix Test Suite Argument Missing.', E_USER_ERROR);
 					}
 
-					echo 'CORRECT SYNTAX:' . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command_alias) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
+					echo PHP_EOL . 'CORRECT SYNTAX:' . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command_alias) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
 
 					if(method_exists($command, 'invalid_command'))
 					{
@@ -1281,9 +1274,22 @@ class pts_client
 
 		if($terminal_width == null)
 		{
-			$chars = -1;
+			$chars = 80;
 
-			if(pts_client::executable_in_path('tput'))
+			if(pts_client::read_env('TERMINAL_WIDTH') != false && is_numeric(pts_client::read_env('TERMINAL_WIDTH')) >= 80)
+			{
+					$terminal_width = pts_client::read_env('TERMINAL_WIDTH');
+			}
+			else if(pts_client::executable_in_path('stty'))
+			{
+				$terminal_width = explode(' ', trim(shell_exec('stty size 2>&1')));
+
+				if(count($terminal_width) == 2 && is_numeric($terminal_width[1]) && $terminal_width[1] >= 80)
+				{
+					$chars = $terminal_width[1];
+				}
+			}
+			else if(pts_client::executable_in_path('tput'))
 			{
 				$terminal_width = trim(shell_exec('tput cols 2>&1'));
 
@@ -1292,11 +1298,6 @@ class pts_client
 					$chars = $terminal_width;
 				}
 			}
-			else if(phodevi::is_windows())
-			{
-				// Need a better way to handle this
-				$chars = 80;
-			}
 
 			$terminal_width = $chars;
 		}
@@ -1439,9 +1440,10 @@ class pts_client
 		{
 			if(count($preset = pts_strings::trim_explode('=', $preset)) == 2)
 			{
-				if(count($preset[0] = pts_strings::trim_explode('.', $preset[0])) == 2)
+				$dot = strrpos($preset[0], '.');
+				if($dot !== false && ($test = substr($preset[0], 0, $dot)) != null && ($option = substr($preset[0], ($dot + 1))) != null)
 				{
-					$values[$preset[0][0]][$preset[0][1]] = $preset[1];
+					$values[$test][$option] = $preset[1];
 				}
 			}
 		}
@@ -1452,6 +1454,20 @@ class pts_client
 	{
 		return tempnam(pts_client::temporary_directory(), 'PTS');
 	}
+	public static function create_temporary_directory($prefix = null)
+	{
+		$tmpdir = pts_client::temporary_directory();
+
+		do
+		{
+			$randname = '/pts-' . $prefix . rand(0, 9999);
+		}
+		while(is_dir($tmpdir . $randname));
+
+		mkdir($tmpdir . $randname);
+
+		return $tmpdir . $randname . '/';
+	}
 	public static function temporary_directory()
 	{
 		if(PHP_VERSION_ID >= 50210)
@@ -1518,7 +1534,7 @@ class pts_client
 	}
 	public static function display_web_page($URL, $alt_text = null, $default_open = true, $auto_open = false)
 	{
-		if(((pts_c::$test_flags & pts_c::auto_mode) && $auto_open == false && $default_open == false) || (pts_client::read_env('DISPLAY') == false && phodevi::is_windows() == false && phodevi::is_macosx() == false) || defined('PHOROMATIC_PROCESS'))
+		if(((pts_c::$test_flags & pts_c::auto_mode) && $auto_open == false && $default_open == false) || (pts_client::read_env('DISPLAY') == false && pts_client::read_env('WAYLAND_DISPLAY') == false && phodevi::is_windows() == false && phodevi::is_macosx() == false) || defined('PHOROMATIC_PROCESS'))
 		{
 			return;
 		}
@@ -1621,62 +1637,115 @@ class pts_client
 
 		return $results;
 	}
-	public static function code_error_handler($error_code, $error_string, $error_file, $error_line)
+	public static function timed_function($function, $function_parameters, $time, $continue_while_true_function = null, $continue_while_true_function_parameters)
 	{
-		if(($error_code & (E_USER_ERROR | E_USER_WARNING | E_USER_NOTICE)))
+		if(($time < 0.5 && $time != -1) || $time > 300)
 		{
-			// It's a self-generated error by pts-core code intentionally
-			return self::user_error_handler($error_code, $error_string, $error_file, $error_line);
+			return;
 		}
 
+		if(function_exists('pcntl_fork'))
+		{
+			$current_pid = function_exists('posix_getpid') ? posix_getpid() : -1;
+			$pid = pcntl_fork();
+
+			if($pid == -1)
+			{
+				trigger_error('Could not fork ' . $function . '.', E_USER_ERROR);
+			}
+			else if($pid)
+			{
+				array_push(self::$forked_pids, $pid);
+			}
+			else
+			{
+				posix_setsid();
+				$loop_continue = true;
+				while($loop_continue && is_file(PTS_USER_LOCK) && ($continue_while_true_function === true || ($loop_continue = call_user_func_array($continue_while_true_function, $continue_while_true_function_parameters))))
+				{
+					call_user_func_array($function, $function_parameters);
+
+					if($time > 0)
+					{
+						sleep($time);
+					}
+					else if($time == -1)
+					{
+						$loop_continue = false;
+					}
+					if($current_pid != -1 && !is_dir('/proc/' . $current_pid))
+					{
+						exit;
+					}
+					clearstatcache();
+				}
+				posix_kill(posix_getpid(), SIGINT);
+				exit(0);
+			}
+		}
+		else
+		{
+			if(is_array($function))
+			{
+				$function = implode(':', $function);
+			}
+
+			trigger_error('php-pcntl must be installed for calling ' . $function . '.', E_USER_ERROR);
+		}
+	}
+	public static function fork($fork_function, $fork_function_parameters)
+	{
+		if(function_exists('pcntl_fork'))
+		{
+			$current_pid = function_exists('posix_getpid') ? posix_getpid() : -1;
+			$pid = pcntl_fork();
+
+			if($pid == -1)
+			{
+				trigger_error('Could not fork ' . $fork_function . '.', E_USER_ERROR);
+			}
+			else if($pid)
+			{
+				// PARENT
+				array_push(self::$forked_pids, $pid);
+				return true;
+			}
+			else
+			{
+				// CHILD
+				// posix_setsid();
+				if(!is_array($fork_function_parameters))
+				{
+					$fork_function_parameters = array($fork_function_parameters);
+				}
+				call_user_func_array($fork_function, $fork_function_parameters);
+				exit(0);
+			}
+		}
+		else
+		{
+			// No PCNTL Support
+			call_user_func_array($fork_function, $fork_function_parameters);
+		}
+
+		return false;
+	}
+	public static function code_error_handler($error_code, $error_string, $error_file, $error_line)
+	{
 		/*if(!(error_reporting() & $error_code))
 		{
 			return;
 		}*/
 
-		switch($error_code)
-		{
-			case E_ERROR:
-			case E_PARSE:
-				$error_type = 'ERROR';
-				break;
-			case E_WARNING:
-			case E_NOTICE:
-				if(($s = strpos($error_string, 'Undefined ')) !== false && ($x = strpos($error_string, ': ', $s)) !== false)
-				{
-					$error_string = 'Undefined: ' . substr($error_string, ($x + 2));
-				}
-				else if(strpos($error_string, 'Name or service not known') !== false || strpos($error_string, 'HTTP request failed') !== false || strpos($error_string, 'fopen') !== false || strpos($error_string, 'file_get_contents') !== false || strpos($error_string, 'Directory not empty') !== false)
-				{
-					// Don't report network errors
-					return;
-				}
-				$error_type = 'NOTICE';
-				break;
-			default:
-				$error_type = $error_code;
-				break;
-		}
-
-		echo PHP_EOL . '[' . $error_type . '] ' . $error_string . ' in ' . basename($error_file) . ':' . $error_line . PHP_EOL;
-
-		if($error_type == 'ERROR')
-		{
-			exit(1);
-		}
-	}
-	public static function user_error_handler($error_code, $error_string, $error_file, $error_line)
-	{
-/*
-
-		trigger_error('Scheisse', E_USER_WARNING);
-		trigger_error('Okay', E_USER_NOTICE);
-		trigger_error('F', E_USER_ERROR);
-*/
 		switch($error_code)
 		{
 			case E_USER_ERROR:
-				$error_type = 'ERROR';
+				$error_type = 'PROBLEM';
+				if(pts_client::is_client_debug_mode() == false)
+				{
+					$error_file = null;
+					$error_line = 0;
+				}
 				break;
 			case E_USER_NOTICE:
 				if(pts_client::is_client_debug_mode() == false)
@@ -1686,12 +1755,71 @@ class pts_client
 				$error_type = 'NOTICE';
 				break;
 			case E_USER_WARNING:
-				$error_type = 'NOTICE'; // Yes, report warnings as a notice label
+				$error_type = 'NOTICE'; // Yes, report warnings as a notice
+				if(pts_client::is_client_debug_mode() == false)
+				{
+					$error_file = null;
+					$error_line = 0;
+				}
+				break;
+			case E_ERROR:
+			case E_PARSE:
+				$error_type = 'ERROR';
+				break;
+			case E_WARNING:
+			case E_NOTICE:
+				$error_type = 'NOTICE';
+				if(($s = strpos($error_string, 'Undefined ')) !== false && ($x = strpos($error_string, ': ', $s)) !== false)
+				{
+					$error_string = 'Undefined: ' . substr($error_string, ($x + 2));
+				}
+				else
+				{
+					$ignore_errors = array(
+						'Name or service not known',
+						'HTTP request failed',
+						'fopen',
+						'fsockopen',
+						'file_get_contents',
+						'failed to connect',
+						'unable to connect',
+						'directory not empty'
+						);
+
+					foreach($ignore_errors as $error_check)
+					{
+						if(stripos($error_string, $error_check) !== false)
+						{
+							return;
+						}
+					}
+				}
+				break;
+			default:
+				$error_type = $error_code;
 				break;
 		}
 
-		echo '[' . $error_type . '] ' . $error_string . (pts_client::is_client_debug_mode() ? ' in ' . basename($error_file) . ':' . $error_line : null) . PHP_EOL;
-		return;
+		if(pts_client::$display != false)
+		{
+			pts_client::$display->triggered_system_error($error_type, $error_string, $error_file, $error_line);
+		}
+		else
+		{
+			echo PHP_EOL . $error_string;
+
+			if($error_file != null && $error_line != null)
+			{
+				echo ' in ' . $error_file . ':' . $error_line;
+			}
+
+			echo PHP_EOL;
+		}
+
+		if($error_type == 'ERROR')
+		{
+			exit(1);
+		}
 	}
 	public static function is_client_debug_mode()
 	{
