@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2013, Phoronix Media
-	Copyright (C) 2010 - 2013, Michael Larabel
+	Copyright (C) 2010 - 2014, Phoronix Media
+	Copyright (C) 2010 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ class pts_openbenchmarking_client
 	private static $openbenchmarking_account = false;
 	private static $client_settings = null;
 
-	public static function upload_test_result(&$object)
+	public static function upload_test_result(&$object, $return_json_data = false)
 	{
 		if($object instanceof pts_test_run_manager)
 		{
@@ -129,9 +129,23 @@ class pts_openbenchmarking_client
 			}
 		}
 
+		$composite_xml_hash = sha1($composite_xml);
+		$composite_xml_type = 'composite_xml';
+
+		// Compress the result file XML if it's big
+		if(isset($composite_xml[50000]) && function_exists('gzdeflate'))
+		{
+			$composite_xml_gz = gzdeflate($composite_xml);
+
+			if($composite_xml_gz != false)
+			{
+				$composite_xml = $composite_xml_gz;
+				$composite_xml_type = 'composite_xml_gz';
+			}
+		}
 		$to_post = array(
-			'composite_xml' => base64_encode($composite_xml),
-			'composite_xml_hash' => sha1($composite_xml),
+			$composite_xml_type => base64_encode($composite_xml),
+			'composite_xml_hash' => $composite_xml_hash,
 			'local_file_name' => $local_file_name,
 			'this_results_identifier' => $results_identifier,
 			'system_logs_zip' => $system_logs,
@@ -146,7 +160,6 @@ class pts_openbenchmarking_client
 
 		$json_response = pts_openbenchmarking::make_openbenchmarking_request('upload_test_result', $to_post);
 		$json_response = json_decode($json_response, true);
-
 		if(!is_array($json_response))
 		{
 			trigger_error('Unhandled Exception', E_USER_ERROR);
@@ -169,28 +182,157 @@ class pts_openbenchmarking_client
 			pts_client::remove_saved_result_file($local_file_name);
 		}
 
+		if($return_json_data)
+		{
+			return isset($json_response['openbenchmarking']['upload']) ? $json_response['openbenchmarking']['upload'] : false;
+		}
+
 		return isset($json_response['openbenchmarking']['upload']['url']) ? $json_response['openbenchmarking']['upload']['url'] : false;
 	}
-	public static function init_account($openbenchmarking)
+	public static function recently_updated_tests($limit = -1)
+	{
+		$available_tests = array();
+
+		foreach(pts_openbenchmarking::linked_repositories() as $repo)
+		{
+			$repo_index = pts_openbenchmarking::read_repository_index($repo);
+
+			if(isset($repo_index['tests']) && is_array($repo_index['tests']))
+			{
+				foreach(array_keys($repo_index['tests']) as $identifier)
+				{
+					if($repo_index['tests'][$identifier]['title'] == null)
+					{
+						continue;
+					}
+
+					$version = array_shift($repo_index['tests'][$identifier]['versions']);
+					$update_time = $repo_index['tests'][$identifier]['last_updated'];
+					$available_tests[$update_time] = $repo . '/' . $identifier . '-' . $version;
+				}
+			}
+		}
+
+		krsort($available_tests);
+
+		if($limit > 0)
+		{
+			$available_tests = array_slice($available_tests, 0, $limit);
+		}
+
+		return $available_tests;
+	}
+	public static function popular_tests($limit = -1, $test_type = null)
+	{
+		$available_tests = array();
+
+		foreach(pts_openbenchmarking::linked_repositories() as $repo)
+		{
+			$repo_index = pts_openbenchmarking::read_repository_index($repo);
+
+			if(isset($repo_index['tests']) && is_array($repo_index['tests']))
+			{
+				foreach(array_keys($repo_index['tests']) as $identifier)
+				{
+					if($repo_index['tests'][$identifier]['title'] == null)
+					{
+						continue;
+					}
+
+					$popularity = $repo_index['tests'][$identifier]['popularity'];
+
+					if($popularity < 1 || ($test_type != null && $repo_index['tests'][$identifier]['test_type'] != $test_type))
+					{
+						continue;
+					}
+
+					$available_tests[$repo . '/' . $identifier] = $popularity;
+				}
+			}
+		}
+
+		asort($available_tests);
+
+		if($limit > 0)
+		{
+			$available_tests = array_slice($available_tests, 0, $limit);
+		}
+
+		return array_keys($available_tests);
+	}
+	public static function search_tests($search, $test_titles_only = true)
+	{
+		$matching_tests = array();
+
+		foreach(pts_openbenchmarking::linked_repositories() as $repo)
+		{
+			$repo_index = pts_openbenchmarking::read_repository_index($repo);
+
+			if(isset($repo_index['tests']) && is_array($repo_index['tests']))
+			{
+				foreach(array_keys($repo_index['tests']) as $identifier)
+				{
+					if(stripos($identifier, $search) !== false || stripos($repo_index['tests'][$identifier]['title'], $search) !== false)
+					{
+						array_push($matching_tests, $repo . '/' . $identifier);
+					}
+					else if($test_titles_only == false && (stripos(implode(' ', $repo_index['tests'][$identifier]['internal_tags']), $search) !== false || stripos($repo_index['tests'][$identifier]['test_type'], $search) !== false || stripos($repo_index['tests'][$identifier]['description'], $search) !== false))
+					{
+						array_push($matching_tests, $repo . '/' . $identifier);
+					}
+				}
+			}
+		}
+
+		return $matching_tests;
+	}
+	public static function tests_available()
+	{
+		$test_count = 0;
+
+		foreach(pts_openbenchmarking::linked_repositories() as $repo)
+		{
+			$repo_index = pts_openbenchmarking::read_repository_index($repo);
+
+			if(isset($repo_index['tests']) && is_array($repo_index['tests']))
+			{
+				$test_count += count($repo_index['tests']);
+			}
+		}
+
+		return $test_count;
+	}
+	public static function init_account($openbenchmarking, $settings)
 	{
 		if(isset($openbenchmarking['user_name']) && isset($openbenchmarking['communication_id']) && isset($openbenchmarking['sav']))
 		{
-			if(IS_FIRST_RUN_TODAY)
+			if(IS_FIRST_RUN_TODAY && pts_network::network_support_available())
 			{
 				// Might as well make sure OpenBenchmarking.org account has the latest system info
 				// But don't do it everytime to preserve bandwidth
 				$openbenchmarking['s_s'] = base64_encode(phodevi::system_software(true));
 				$openbenchmarking['s_h'] = base64_encode(phodevi::system_hardware(true));
+
+				$return_state = pts_openbenchmarking::make_openbenchmarking_request('account_verify', $openbenchmarking);
+				$json = json_decode($return_state, true);
+
+				if(isset($json['openbenchmarking']['account']['valid']))
+				{
+					// The account is valid
+					self::$openbenchmarking_account = $openbenchmarking;
+					self::$client_settings = $json['openbenchmarking']['account']['settings'];
+					pts_storage_object::set_in_file(PTS_CORE_STORAGE, 'openbenchmarking_account_settings', $json['openbenchmarking']['account']['settings']);
+				}
+				else
+				{
+					pts_storage_object::set_in_file(PTS_CORE_STORAGE, 'openbenchmarking', false);
+					trigger_error('Invalid OpenBenchmarking.org account supplied, please re-login.', E_USER_ERROR);
+				}
 			}
-
-			$return_state = pts_openbenchmarking::make_openbenchmarking_request('account_verify', $openbenchmarking);
-			$json = json_decode($return_state, true);
-
-			if(isset($json['openbenchmarking']['account']['valid']))
+			else
 			{
-				// The account is valid
 				self::$openbenchmarking_account = $openbenchmarking;
-				self::$client_settings = $json['openbenchmarking']['account']['settings'];
+				self::$client_settings = $settings;
 			}
 		}
 	}
@@ -221,6 +363,33 @@ class pts_openbenchmarking_client
 
 		return true;
 	}
+	public static function read_repository_test_profile_attribute($test_profile, $attribute)
+	{
+		list($repo, $tp) = explode('/', $test_profile);
+		$tp = substr($tp, 0, strrpos($tp, '-'));
+		$repo_index = pts_openbenchmarking::read_repository_index($repo);
+
+		return isset($repo_index['tests'][$tp][$attribute]) ? $repo_index['tests'][$tp][$attribute] : null;
+	}
+	public static function popular_openbenchmarking_results()
+	{
+		$index_file = PTS_OPENBENCHMARKING_SCRATCH_PATH . 'popular.results';
+
+		if(!is_file($index_file) || filemtime($index_file) < (time() - 1800))
+		{
+			// Refresh the repository change-log just once a day should be fine
+			$server_index = pts_openbenchmarking::make_openbenchmarking_request('interesting_results');
+
+			if(json_decode($server_index) != false)
+			{
+				file_put_contents($index_file, $server_index);
+			}
+		}
+
+		$results = is_file($index_file) ? json_decode(file_get_contents($index_file), true) : false;
+
+		return $results ? $results['results'] : false;
+	}
 	public static function fetch_repository_changelog($repo_name)
 	{
 		$index_file = PTS_OPENBENCHMARKING_SCRATCH_PATH . $repo_name . '.changes';
