@@ -75,10 +75,15 @@ class pts_test_execution
 
 		if(!$cache_share_present)
 		{
-			pts_tests::call_test_script($test_run_request->test_profile, 'pre', 'Running Pre-Test Script', $test_directory, $extra_runtime_variables, true);
+			$pre_output = pts_tests::call_test_script($test_run_request->test_profile, 'pre', 'Running Pre-Test Script', $pts_test_arguments, $extra_runtime_variables, true);
+
+			if($pre_output != null && (pts_c::$test_flags & pts_c::debug_mode))
+			{
+				pts_client::$display->test_run_instance_output($pre_output);
+			}
 		}
 
-		pts_user_io::display_interrupt_message($test_run_request->test_profile->get_pre_run_message());
+		pts_client::$display->display_interrupt_message($test_run_request->test_profile->get_pre_run_message());
 		$runtime_identifier = time();
 		$execute_binary_prepend = '';
 
@@ -253,7 +258,7 @@ class pts_test_execution
 				}
 			}
 
-			if($is_expected_last_run && $test_run_request->test_result_buffer->get_count() > floor(($i - 2) / 2))
+			if($is_expected_last_run && $test_run_request->test_result_buffer->get_count() > floor(($i - 2) / 2) && !$cache_share_present && $test_run_manager->do_dynamic_run_count())
 			{
 				// The later check above ensures if the test is failing often the run count won't uselessly be increasing
 				// Should we increase the run count?
@@ -264,7 +269,7 @@ class pts_test_execution
 					// At least one run passed, but at least one run failed to produce a result. Increase count to try to get more successful runs
 					$increase_run_count = $defined_times_to_run - $test_run_request->test_result_buffer->get_count();
 				}
-				else if($test_run_request->test_result_buffer->get_count() >= 2 && $test_run_manager->do_dynamic_run_count())
+				else if($test_run_request->test_result_buffer->get_count() >= 2)
 				{
 					// Dynamically increase run count if needed for statistical significance or other reasons
 					$increase_run_count = $test_run_manager->increase_run_count_check($test_run_request, $defined_times_to_run, $test_run_time);
@@ -292,7 +297,12 @@ class pts_test_execution
 			{
 				if($cache_share_present == false)
 				{
-					pts_tests::call_test_script($test_run_request->test_profile, 'interim', 'Running Interim Test Script', $test_directory, $extra_runtime_variables, true);
+					$interim_output = pts_tests::call_test_script($test_run_request->test_profile, 'interim', 'Running Interim Test Script', $pts_test_arguments, $extra_runtime_variables, true);
+
+					if($interim_output != null && (pts_c::$test_flags & pts_c::debug_mode))
+					{
+						pts_client::$display->test_run_instance_output($interim_output);
+					}
 					sleep(2); // Rest for a moment between tests
 				}
 
@@ -332,7 +342,12 @@ class pts_test_execution
 
 		if($cache_share_present == false)
 		{
-			pts_tests::call_test_script($test_run_request->test_profile, 'post', 'Running Post-Test Script', $test_directory, $extra_runtime_variables, true);
+			$post_output = pts_tests::call_test_script($test_run_request->test_profile, 'post', 'Running Post-Test Script', $pts_test_arguments, $extra_runtime_variables, true);
+
+			if($post_output != null && (pts_c::$test_flags & pts_c::debug_mode))
+			{
+				pts_client::$display->test_run_instance_output($post_output);
+			}
 		}
 
 		if($abort_testing)
@@ -465,7 +480,7 @@ class pts_test_execution
 
 		pts_client::$display->test_run_end($test_run_request);
 
-		pts_user_io::display_interrupt_message($test_run_request->test_profile->get_post_run_message());
+		pts_client::$display->display_interrupt_message($test_run_request->test_profile->get_post_run_message());
 		pts_module_manager::module_process('__post_test_run', $test_run_request);
 		$report_elapsed_time = $cache_share_present == false && $test_run_request->get_result() != 0;
 		pts_tests::update_test_install_xml($test_run_request->test_profile, ($report_elapsed_time ? $time_test_elapsed : 0));
