@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2013, Phoronix Media
-	Copyright (C) 2010 - 2013, Michael Larabel
+	Copyright (C) 2010 - 2014, Phoronix Media
+	Copyright (C) 2010 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -41,6 +41,10 @@ class pts_test_install_manager
 		{
 			//pts_client::$display->test_install_error($test_profile->get_identifier() . ' is being skipped from installation.');
 		}
+		else if(($e = pts_client::read_env('SKIP_TESTING_SUBSYSTEMS')) != false && in_array(strtolower($test_profile->get_test_hardware_type()), pts_strings::comma_explode(strtolower($e))))
+		{
+			//pts_client::$display->test_install_error($test_profile->get_identifier() . ' is being skipped from installation.');
+		}
 		else
 		{
 			$added = pts_arrays::unique_push($this->tests_to_install, new pts_test_install_request($test_profile));
@@ -55,7 +59,7 @@ class pts_test_install_manager
 
 		foreach($this->tests_to_install as $i => &$test_install_request)
 		{
-			$test_install_request->generate_download_object_list();
+            $test_install_request->generate_download_object_list();
 			pts_client::$display->test_install_progress_update(($i / $test_count));
 		}
 		pts_client::$display->test_install_progress_completed();
@@ -76,7 +80,7 @@ class pts_test_install_manager
 		}
 		pts_client::$display->test_install_progress_completed();
 	}
-	public function remote_files_available_in_download_caches()
+	public static function remote_files_available_in_download_caches()
 	{
 		$remote_download_files = array();
 
