@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2013, Phoronix Media
-	Copyright (C) 2010 - 2013, Michael Larabel
+	Copyright (C) 2010 - 2014, Phoronix Media
+	Copyright (C) 2010 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,7 +25,10 @@ class pts_test_installer
 	public static function standard_install($items_to_install, $test_flags = 0)
 	{
 		// Refresh the pts_client::$display in case we need to run in debug mode
-		pts_client::init_display_mode();
+		if(pts_client::$display == false || ($test_flags != 0 && !(pts_client::$display instanceof pts_websocket_display_mode)))
+		{
+			pts_client::init_display_mode($test_flags);
+		}
 
 		// Create a lock
 		$lock_path = pts_client::temporary_directory() . '/phoronix-test-suite.active';
@@ -56,7 +59,7 @@ class pts_test_installer
 	{
 		if(count($test_profiles) == 0)
 		{
-			pts_client::$display->generic_error('No Tests Found For Installation.');
+			trigger_error('No Tests Found For Installation.', E_USER_ERROR);
 			return false;
 		}
 
@@ -113,6 +116,7 @@ class pts_test_installer
 		while(($test_install_request = $test_install_manager->next_in_install_queue()) != false)
 		{
 			pts_client::$display->test_install_start($test_install_request->test_profile->get_identifier());
+			$test_install_request->special_environment_vars['INSTALL_FOOTNOTE'] = $test_install_request->test_profile->get_install_dir() . 'install-footnote';
 			$installed = pts_test_installer::install_test_process($test_install_request);
 			$compiler_data = pts_test_installer::end_compiler_mask($test_install_request);
 
@@ -124,13 +128,21 @@ class pts_test_installer
 					pts_openbenchmarking_client::upload_usage_data('test_install', array($test_install_request, $test_install_request->install_time_duration));
 				}
 
-				pts_tests::update_test_install_xml($test_install_request->test_profile, $test_install_request->install_time_duration, true, $compiler_data);
+				$install_footnote = null;
+				if(is_file($test_install_request->special_environment_vars['INSTALL_FOOTNOTE']))
+				{
+					$install_footnote = pts_file_io::file_get_contents($test_install_request->special_environment_vars['INSTALL_FOOTNOTE']);
+				}
+
+				pts_tests::update_test_install_xml($test_install_request->test_profile, $test_install_request->install_time_duration, true, $compiler_data, $install_footnote);
 				array_push($test_profiles, $test_install_request->test_profile);
 			}
 			else
 			{
 				array_push($failed_installs, $test_install_request);
 			}
+
+			pts_file_io::unlink($test_install_request->special_environment_vars['INSTALL_FOOTNOTE']);
 		}
 		pts_module_manager::module_process('__post_install_process', $test_install_manager);
 		pts_download_speed_manager::save_data();
@@ -413,6 +425,12 @@ class pts_test_installer
 	}
 	public static function create_compiler_mask(&$test_install_request)
 	{
+		if(phodevi::is_bsd())
+		{
+			// XXX: Using the compiler-mask causes a number of tests to fail to properly install due to compiler issues with at least PC-BSD 10.0
+			return false;
+		}
+
 		// or pass false to $test_install_request to bypass the test checks
 		$compilers = array();
 
@@ -680,11 +698,11 @@ class pts_test_installer
 					}
 				}
 
-				pts_user_io::display_interrupt_message($pre_install_message);
+				pts_client::$display->display_interrupt_message($pre_install_message);
 				$install_time_length_start = microtime(true);
 				$install_log = pts_tests::call_test_script($test_install_request->test_profile, 'install', null, $test_install_directory, $test_install_request->special_environment_vars, false);
 				$test_install_request->install_time_duration = ceil(microtime(true) - $install_time_length_start);
-				pts_user_io::display_interrupt_message($post_install_message);
+				pts_client::$display->display_interrupt_message($post_install_message);
 
 				if(!empty($install_log))
 				{
@@ -713,7 +731,7 @@ class pts_test_installer
 							copy($test_install_directory . 'install.log', $test_install_directory . 'install-failed.log');
 						}
 
-						pts_test_installer::setup_test_install_directory($test_install_request, true); // Remove installed files from the bunked installation
+						//pts_test_installer::setup_test_install_directory($test_install_request, true); // Remove installed files from the bunked installation
 						pts_client::$display->test_install_error('The installer exited with a non-zero exit status.');
 						if($install_error != null)
 						{
@@ -786,7 +804,7 @@ class pts_test_installer
 					{
 						list($md5, $file) = explode(' ', $md5_line);
 
-						if($md5_file == $filename)
+						if($file == $filename)
 						{
 							if($md5 == $real_md5)
 							{
@@ -830,7 +848,7 @@ class pts_test_installer
 					{
 						list($sha256, $file) = explode(' ', $sha256_line);
 
-						if($sha256_file == $filename)
+						if($file == $filename)
 						{
 							if($sha256 == $real_sha256)
 							{
