@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2013, Phoronix Media
-	Copyright (C) 2009 - 2013, Michael Larabel
+	Copyright (C) 2009 - 2014, Phoronix Media
+	Copyright (C) 2009 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ class pts_test_run_manager
 	private $allow_sharing_of_results = true;
 	private $auto_upload_to_openbenchmarking = false;
 	private $is_pcqs = false;
+	private $openbenchmarking_results_data = false;
 
 	private $do_dynamic_run_count = false;
 	private $dynamic_run_count_on_length_or_less;
@@ -70,6 +71,10 @@ class pts_test_run_manager
 	{
 		return $this->do_dynamic_run_count;
 	}
+	public function disable_dynamic_run_count()
+	{
+		$this->do_dynamic_run_count = false;
+	}
 	public function auto_upload_to_openbenchmarking($do = true)
 	{
 		$this->auto_upload_to_openbenchmarking = ($do == true);
@@ -251,33 +256,6 @@ class pts_test_run_manager
 	{
 		$this->results_identifier = self::clean_results_identifier($identifier);
 	}
-	public static function recently_saved_test_results()
-	{
-		$recent_results = array();
-		foreach(pts_file_io::glob(PTS_SAVE_RESULTS_PATH . '*/composite.xml') as $composite)
-		{
-			$recent_results[filemtime($composite)] = basename(dirname($composite));
-		}
-
-		if(count($recent_results) > 0)
-		{
-			krsort($recent_results);
-			$recent_results = array_slice($recent_results, 0, 4, true);
-			$res_length = strlen(pts_strings::find_longest_string($recent_results)) + 2;
-			$current_time = time();
-
-			foreach($recent_results as $m_time => &$recent_result)
-			{
-				$days = floor(($current_time - $m_time) / 86400);
-				$recent_result = sprintf('%-' . $res_length . 'ls [%-ls]', $recent_result, ($days == 0 ? 'Today' : pts_strings::days_ago_format_string($days) . ' old'));
-			}
-			echo PHP_EOL . 'Recently Saved Test Results:' . PHP_EOL;
-			echo pts_user_io::display_text_list($recent_results) . PHP_EOL;
-			return true;
-		}
-
-		return false;
-	}
 	public function prompt_save_name()
 	{
 		if($this->file_name != null)
@@ -300,7 +278,7 @@ class pts_test_run_manager
 			// Be of help to the user by showing recently saved test results
 			if($save_name == null)
 			{
-				self::recently_saved_test_results();
+				pts_tests::recently_saved_results();
 
 			}
 
@@ -370,8 +348,8 @@ class pts_test_run_manager
 			{
 				if($times_tried == 0 && ($env_identifier = pts_client::read_env('TEST_RESULTS_IDENTIFIER')))
 				{
-					$results_identifier = isset($env_identifier) ? $env_identifier : null;
-					echo 'Test Identifier: ' . self::clean_results_identifier($results_identifier) . PHP_EOL;
+					$results_identifier = isset($env_identifier) ? self::clean_results_identifier($env_identifier) : null;
+					echo 'Test Identifier: ' . $results_identifier . PHP_EOL;
 				}
 				else if((pts_c::$test_flags ^ pts_c::auto_mode))
 				{
@@ -390,55 +368,80 @@ class pts_test_run_manager
 			}
 			while((!$no_repeated_tests && $identifier_pos != -1) || (isset($current_hardware[$identifier_pos]) && $current_hardware[$identifier_pos] != phodevi::system_hardware(true)) || (isset($current_software[$identifier_pos]) && $current_software[$identifier_pos] != phodevi::system_software(true)));
 		}
+		else if(($env_identifier = pts_client::read_env('TEST_RESULTS_IDENTIFIER')))
+		{
+			$results_identifier = self::clean_results_identifier($env_identifier);
+		}
+
 
 		if(empty($results_identifier))
 		{
-			// If the save result identifier is empty, try to come up with something based upon the tests being run.
-			$subsystem_r = array();
-			$subsystems_to_test = $this->subsystems_under_test();
-
-			if(pts_result_file::is_test_result_file($this->file_name))
-			{
-				$result_file = new pts_result_file($this->file_name);
-				$result_file_intent = pts_result_file_analyzer::analyze_result_file_intent($result_file);
-
-				if(is_array($result_file_intent) && $result_file_intent[0] != 'Unknown')
-				{
-					array_unshift($subsystems_to_test, $result_file_intent[0]);
-				}
-			}
-
-			foreach($subsystems_to_test as $subsystem)
-			{
-				$components = pts_result_file_analyzer::system_component_string_to_array(phodevi::system_hardware(true) . ', ' . phodevi::system_software(true));
-				if(isset($components[$subsystem]))
-				{
-					$subsystem_name = pts_strings::trim_search_query($components[$subsystem]);
-
-					if(phodevi::is_vendor_string($subsystem_name) && !in_array($subsystem_name, $subsystem_r))
-					{
-						array_push($subsystem_r, $subsystem_name);
-					}
-					if(isset($subsystem_r[2]) || isset($subsystem_name[19]))
-					{
-						break;
-					}
-				}
-			}
-
-			if(isset($subsystem_r[0]))
-			{
-				$results_identifier = implode(' - ', $subsystem_r);
-			}
-
-			if(empty($results_identifier))
-			{
-				$results_identifier = date('Y-m-d H:i');
-			}
+			$results_identifier = $this->auto_generate_results_identifier();
 		}
 
 		$this->results_identifier = $results_identifier;
 	}
+	public function auto_generate_results_identifier()
+	{
+		// If the save result identifier is empty, try to come up with something based upon the tests being run.
+		$results_identifier = null;
+		$subsystem_r = array();
+		$subsystems_to_test = $this->subsystems_under_test();
+
+		if(pts_result_file::is_test_result_file($this->file_name))
+		{
+			$result_file = new pts_result_file($this->file_name);
+			$result_file_intent = pts_result_file_analyzer::analyze_result_file_intent($result_file);
+
+			if(is_array($result_file_intent) && $result_file_intent[0] != 'Unknown')
+			{
+				array_unshift($subsystems_to_test, $result_file_intent[0]);
+			}
+		}
+
+		foreach($subsystems_to_test as $subsystem)
+		{
+			$components = pts_result_file_analyzer::system_component_string_to_array(phodevi::system_hardware(true) . ', ' . phodevi::system_software(true));
+			if(isset($components[$subsystem]))
+			{
+				$subsystem_name = pts_strings::trim_search_query($components[$subsystem]);
+
+				if(phodevi::is_vendor_string($subsystem_name) && !in_array($subsystem_name, $subsystem_r))
+				{
+					array_push($subsystem_r, $subsystem_name);
+				}
+				if(isset($subsystem_r[2]) || isset($subsystem_name[19]))
+				{
+					break;
+				}
+			}
+		}
+
+		if(isset($subsystem_r[0]))
+		{
+			$results_identifier = implode(' - ', $subsystem_r);
+		}
+
+		if(empty($results_identifier) && (pts_c::$test_flags ^ pts_c::batch_mode))
+		{
+			$results_identifier = phodevi::read_property('cpu', 'model') . ' - ' . phodevi::read_property('gpu', 'model') . ' - ' . phodevi::read_property('motherboard', 'identifier');
+		}
+
+		if(strlen($results_identifier) > 55)
+		{
+			$results_identifier = substr($results_identifier, 0, 54);
+			$results_identifier = substr($results_identifier, 0, strrpos($results_identifier, ' '));
+		}
+
+		if(empty($results_identifier))
+		{
+			$results_identifier = date('Y-m-d H:i');
+		}
+
+		$this->results_identifier = $results_identifier;
+
+		return $results_identifier;
+	}
 	public static function clean_results_identifier($results_identifier)
 	{
 		$results_identifier = trim(pts_client::swap_variables($results_identifier, array('pts_client', 'user_run_save_variables')));
@@ -462,7 +465,7 @@ class pts_test_run_manager
 
 		if($this->pre_run_message != null)
 		{
-			pts_user_io::display_interrupt_message($this->pre_run_message);
+			pts_client::$display->display_interrupt_message($this->pre_run_message);
 		}
 
 		// Hook into the module framework
@@ -535,7 +538,7 @@ class pts_test_run_manager
 
 		if($this->post_run_message != null)
 		{
-			pts_user_io::display_interrupt_message($this->post_run_message);
+			pts_client::$display->display_interrupt_message($this->post_run_message);
 		}
 
 		self::$test_run_process_active = -1;
@@ -587,7 +590,12 @@ class pts_test_run_manager
 		else if(pts_file_io::unlink(PTS_USER_PATH . 'skip-test'))
 		{
 			// Just skip the current test and do not save the results, but continue testing
-			continue;
+			return true;
+		}
+		else if(pts_client::read_env('LIMIT_ELAPSED_TEST_TIME') > 0 && (PTS_INIT_TIME + (pts_client::read_env('LIMIT_ELAPSED_TEST_TIME') * 60)) > time())
+		{
+			// Allocated amount of time has expired
+			return false;
 		}
 
 		$test_successful = false;
@@ -667,6 +675,10 @@ class pts_test_run_manager
 		{
 			$json_report_attributes['compiler-options'] = $t;
 		}
+		if(($t = $test_run_request->test_profile->test_installation->get_install_footnote()))
+		{
+			$json_report_attributes['install-footnote'] = $t;
+		}
 		if(($t = $test_run_request->get_min_result()) != 0)
 		{
 			$json_report_attributes['min-result'] = $t;
@@ -694,7 +706,10 @@ class pts_test_run_manager
 	{
 		// Refresh the pts_client::$display in case we need to run in debug mode
 		$test_flags |= pts_c::is_run_process;
-		pts_client::init_display_mode($test_flags);
+		if(pts_client::$display == false || ($test_flags != 0 && !(pts_client::$display instanceof pts_websocket_display_mode)))
+		{
+			pts_client::init_display_mode($test_flags);
+		}
 		pts_client::set_test_flags($test_flags);
 		$to_run = pts_types::identifiers_to_objects($to_run);
 
@@ -707,14 +722,14 @@ class pts_test_run_manager
 
 			if(self::$batch_mode_options['Configured'] == false && (pts_c::$test_flags ^ pts_c::auto_mode))
 			{
-				pts_client::$display->generic_error('The batch mode must first be configured.' . PHP_EOL . 'To configure, run phoronix-test-suite batch-setup');
+				trigger_error('The batch mode must first be configured.' . PHP_EOL . 'To configure, run phoronix-test-suite batch-setup', E_USER_ERROR);
 				return false;
 			}
 		}
 
 		if(!is_writable(pts_client::test_install_root_path()))
 		{
-			pts_client::$display->generic_error('The test installation directory is not writable.' . PHP_EOL . 'Location: ' . pts_client::test_install_root_path());
+			trigger_error('The test installation directory is not writable.' . PHP_EOL . 'Location: ' . pts_client::test_install_root_path(), E_USER_ERROR);
 			return false;
 		}
 
@@ -725,8 +740,7 @@ class pts_test_run_manager
 		}
 		else if(count($to_run) == 0)
 		{
-			pts_client::$display->generic_error('You must enter at least one test, suite, or result identifier to run.');
-
+			trigger_error('You must enter at least one test, suite, or result identifier to run.', E_USER_ERROR);
 			return false;
 		}
 
@@ -807,8 +821,9 @@ class pts_test_run_manager
 				$notes['disk-mount-options'] = $mount_options['mount-options'];
 			}
 		}
-		if($show_all || in_array('Processor', $test_hardware_types) || in_array('System', $test_hardware_types))
+		if(true || $show_all || in_array('Processor', $test_hardware_types) || in_array('System', $test_hardware_types))
 		{
+			// XXX probably makes sense always reporting the CPU scaling governor
 			$scaling_governor = phodevi::read_property('cpu', 'scaling-governor');
 			if($scaling_governor)
 			{
@@ -870,8 +885,21 @@ class pts_test_run_manager
 			pts_client::save_result_file($this->result_file_writer, $this->get_file_name());
 			pts_module_manager::module_process('__event_results_saved', $this);
 			//echo PHP_EOL . 'Results Saved To: ; . PTS_SAVE_RESULTS_PATH . $this->get_file_name() . ;/composite.xml' . PHP_EOL;
-			$auto_open = (pts_c::$test_flags & pts_c::batch_mode) ? self::$batch_mode_options['OpenBrowser'] : false;
-			pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/index.html', null, true, $auto_open);
+
+			if(!(pts_c::$test_flags & pts_c::auto_mode))
+			{
+				if((pts_c::$test_flags & pts_c::batch_mode))
+				{
+					if(self::$batch_mode_options['OpenBrowser'])
+					{
+						pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/index.html', null, true, true);
+					}
+				}
+				else
+				{
+					pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/index.html', null, true, false);
+				}
+			}
 
 			if($this->allow_sharing_of_results && pts_network::network_support_available())
 			{
@@ -883,7 +911,7 @@ class pts_test_run_manager
 				{
 					$upload_results = self::$batch_mode_options['UploadResults'];
 				}
-				else if((pts_c::$test_flags ^ pts_c::auto_mode))
+				else if(!(pts_c::$test_flags & pts_c::auto_mode))
 				{
 					$upload_results = pts_user_io::prompt_bool_input('Would you like to upload the results to OpenBenchmarking.org', true);
 				}
@@ -894,13 +922,13 @@ class pts_test_run_manager
 
 				if($upload_results)
 				{
-					$upload_url = pts_openbenchmarking::upload_test_result($this);
+					$this->openbenchmarking_results_data = pts_openbenchmarking::upload_test_result($this, true);
 
-					if(!empty($upload_url))
+					if($this->get_results_url())
 					{
-						if((pts_c::$test_flags ^ pts_c::auto_mode) && pts_openbenchmarking_client::auto_upload_results() == false)
+						if(!(pts_c::$test_flags & pts_c::auto_mode) && pts_openbenchmarking_client::auto_upload_results() == false)
 						{
-							pts_client::display_web_page($upload_url, 'Do you want to launch OpenBenchmarking.org', true);
+							pts_client::display_web_page($this->get_results_url(), 'Do you want to launch OpenBenchmarking.org', true);
 						}
 					}
 					else
@@ -911,11 +939,19 @@ class pts_test_run_manager
 			}
 		}
 	}
+	public function get_results_url()
+	{
+		return isset($this->openbenchmarking_results_data['url']) ? $this->openbenchmarking_results_data['url'] : false;
+	}
+	public function get_result_upload_data()
+	{
+		return $this->openbenchmarking_results_data;
+	}
 	public static function set_batch_mode($custom_preset = false)
 	{
 		self::$batch_mode_options = array(
 			'UploadResults' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/UploadResults', 'TRUE'),
-			'SaveResults' => pts_config::read_user_config('PhoronixTestSuite/Options/BatchMode/SaveResults', 'TRUE'),
+			'SaveResults' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/SaveResults', 'TRUE'),
 			'PromptForTestDescription' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestDescription', 'FALSE'),
 			'RunAllTestCombinations' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/RunAllTestCombinations', 'TRUE'),
 			'PromptSaveName' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptSaveName', 'FALSE'),
@@ -944,14 +980,14 @@ class pts_test_run_manager
 		{
 			if($skip_tests && (in_array($run_object->get_identifier(false), $skip_tests) || ($run_object instanceof pts_test_profile && in_array($run_object->get_identifier_base_name(), $skip_tests))))
 			{
-				echo 'Skipping: ' . $run_object->get_identifier() . PHP_EOL;
+				pts_client::$display->generic_sub_heading('Skipping: ' . $run_object->get_identifier());
 				continue;
 			}
 			else if($run_object instanceof pts_test_profile)
 			{
 				if($run_object->get_title() == null)
 				{
-					echo 'Not A Test: ' . $run_object . PHP_EOL;
+					pts_client::$display->generic_sub_heading('Not A Test: ' . $run_object);
 					continue;
 				}
 				else
@@ -993,11 +1029,11 @@ class pts_test_run_manager
 					continue;
 				}
 			}
-			else if($run_object instanceof pts_test_suite || $run_object instanceof pts_virtual_test_suite)
+			else if($run_object instanceof pts_test_suite || $run_object instanceof pts_virtual_test_suite|| $run_object instanceof pts_virtual_test_queue)
 			{
 				if($run_object->is_core_version_supported() == false)
 				{
-					echo $run_object->get_title() . ' is a suite not supported by this version of the Phoronix Test Suite.' . PHP_EOL;
+					pts_client::$display->generic_sub_heading($run_object->get_title() . ' is a suite not supported by this version of the Phoronix Test Suite.');
 					continue;
 				}
 
@@ -1027,7 +1063,7 @@ class pts_test_run_manager
 			}
 			else
 			{
-				echo 'Not Recognized: ' . $run_object . PHP_EOL;
+				pts_client::$display->generic_sub_heading('Not Recognized: ' . $run_object);
 				continue;
 			}
 
@@ -1042,7 +1078,7 @@ class pts_test_run_manager
 
 			if(count($tests_missing) == 1)
 			{
-				pts_client::$display->generic_error($tests_missing[0] . ' is not installed.');
+				trigger_error($tests_missing[0] . ' is not installed.', E_USER_ERROR);
 				// PHP_EOL . 'To install, run: phoronix-test-suite install ' . $tests_missing[0]
 			}
 			else
@@ -1067,9 +1103,9 @@ class pts_test_run_manager
 
 		return true;
 	}
-	public function auto_save_results($save_name, $result_identifier, $description = null)
+	public function auto_save_results($save_name, $result_identifier, $description = null, $is_new_save = false)
 	{
-		$this->set_save_name($save_name, false);
+		$this->set_save_name($save_name, $is_new_save);
 		$this->set_results_identifier($result_identifier);
 		$this->set_description($description);
 	}
@@ -1186,6 +1222,10 @@ class pts_test_run_manager
 			{
 				$save_results = self::$batch_mode_options['SaveResults'];
 			}
+			else if((pts_c::$test_flags & pts_c::debug_mode))
+			{
+				$save_results = false;
+			}
 			else
 			{
 				$save_results = pts_user_io::prompt_bool_input('Would you like to save these test results', true);
@@ -1223,6 +1263,7 @@ class pts_test_run_manager
 					}
 					else if((pts_c::$test_flags ^ pts_c::auto_mode))
 					{
+						//echo PHP_EOL . 'Current Title: ' . $this->file_name_title . PHP_EOL;
 						pts_client::$display->generic_heading('If you wish, enter a new description below to better describe this result set / system configuration under test.' . PHP_EOL . 'Press ENTER to proceed without changes.');
 						echo 'Current Description: ' . $this->run_description . PHP_EOL . PHP_EOL . 'New Description: ';
 						$new_test_description = pts_user_io::read_user_input();
@@ -1387,6 +1428,13 @@ class pts_test_run_manager
 					$this->add_test_result_object($result_object);
 				}
 			}
+			else if($run_object instanceof pts_virtual_test_queue)
+			{
+				foreach($run_object->get_contained_test_result_objects() as $result_object)
+				{
+					$this->add_test_result_object($result_object);
+				}
+			}
 			else if($run_object instanceof pts_result_file)
 			{
 				// Print the $to_run ?
@@ -1395,6 +1443,7 @@ class pts_test_run_manager
 				$result_objects = $run_object->get_result_objects();
 
 				$this->set_save_name($run_object->get_identifier(), false);
+				$this->file_name_title = $run_object->get_title();
 
 				pts_module_manager::process_environment_variables_string_to_set($preset_vars);
 
@@ -1460,7 +1509,7 @@ class pts_test_run_manager
 			}
 			else
 			{
-				pts_client::$display->generic_error($to_run . ' is not recognized.');
+				trigger_error($run_object . ' is not recognized.', E_USER_ERROR);
 				continue;
 			}
 		}
@@ -1474,6 +1523,10 @@ class pts_test_run_manager
 			// Sort the run order so that all tests that are similar are grouped together, etc
 			usort($this->tests_to_run, array('pts_test_run_manager', 'cmp_result_object_sort'));
 		}
+		if(pts_client::read_env('RUN_TESTS_IN_RANDOM_ORDER'))
+		{
+			shuffle($this->tests_to_run);
+		}
 
 		$this->prompt_save_results = $run_contains_a_no_result_type == false || $unique_test_count > 1;
 		$this->force_save_results = $this->force_save_results || $request_results_save;
@@ -1503,7 +1556,7 @@ class pts_test_run_manager
 		$valid_test_profile = true;
 		$test_type = $test_profile->get_test_hardware_type();
 		$skip_tests = pts_client::read_env('SKIP_TESTS') ? pts_strings::comma_explode(pts_client::read_env('SKIP_TESTS')) : false;
-		$only_test_types = ($e = pts_client::read_env('ONLY_TEST_TYPES')) ? pts_strings::comma_explode($e) : false;
+		$skip_test_subsystems = pts_client::read_env('SKIP_TESTING_SUBSYSTEMS') ? pts_strings::comma_explode(strtolower(pts_client::read_env('SKIP_TESTING_SUBSYSTEMS'))) : false;
 		$display_driver = phodevi::read_property('system', 'display-driver');
 		$gpu = phodevi::read_name('gpu');
 
@@ -1511,7 +1564,7 @@ class pts_test_run_manager
 		{
 			$valid_test_profile = false;
 		}
-		else if($test_type == 'Graphics' && pts_client::read_env('DISPLAY') == false && phodevi::is_windows() == false && phodevi::is_macosx() == false)
+		else if($test_type == 'Graphics' && pts_client::read_env('DISPLAY') == false && pts_client::read_env('WAYLAND_DISPLAY') == false && phodevi::is_windows() == false && phodevi::is_macosx() == false)
 		{
 			$report_errors && pts_client::$display->test_run_error('No display server was found, cannot run ' . $test_profile);
 			$valid_test_profile = false;
@@ -1532,7 +1585,7 @@ class pts_test_run_manager
 			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
 		}
-		else if($only_test_types && !in_array($test_profile->get_test_hardware_type(), $only_test_types))
+		else if($skip_test_subsystems && in_array(strtolower($test_profile->get_test_hardware_type()), $skip_test_subsystems))
 		{
 			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
