@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,19 +25,12 @@ class pts_tests
 	public static function installed_tests()
 	{
 		$cleaned_tests = array();
-
-		foreach(pts_file_io::glob(pts_client::test_install_root_path() . '*') as $repo_path)
+		$repo = '*';
+		$install_root_path = pts_client::test_install_root_path();
+		$install_root_path_length = strlen($install_root_path);
+		foreach(pts_file_io::glob($install_root_path . $repo . '/*/pts-install.xml') as $identifier_path)
 		{
-			$repo = basename($repo_path);
-			foreach(pts_file_io::glob($repo_path . '/*') as $identifier_path)
-			{
-				if(is_file($identifier_path . '/pts-install.xml'))
-				{
-					$identifier = basename($identifier_path);
-
-					array_push($cleaned_tests, $repo . '/' . $identifier);
-				}
-			}
+			array_push($cleaned_tests, substr(dirname($identifier_path), $install_root_path_length));
 		}
 
 		return $cleaned_tests;
@@ -206,7 +199,7 @@ class pts_tests
 
 		return $result;
 	}
-	public static function update_test_install_xml(&$test_profile, $this_duration = 0, $is_install = false, $compiler_data = null)
+	public static function update_test_install_xml(&$test_profile, $this_duration = 0, $is_install = false, $compiler_data = null, $install_footnote = null)
 	{
 		// Refresh/generate an install XML for pts-install.xml
 		if($test_profile->test_installation == false)
@@ -227,6 +220,7 @@ class pts_tests
 		}
 
 		$compiler_data = $is_install ? $compiler_data : $test_profile->test_installation->get_compiler_data();
+		$install_footnote = $is_install ? $install_footnote : $test_profile->test_installation->get_install_footnote();
 		$test_version = $is_install ? $test_profile->get_test_profile_version() : $test_profile->test_installation->get_installed_version();
 		$test_checksum = $is_install ? $test_profile->get_installer_checksum() : $test_profile->test_installation->get_installed_checksum();
 		$sys_identifier = $is_install ? phodevi::system_id_string() : $test_profile->test_installation->get_installed_system_identifier();
@@ -255,6 +249,7 @@ class pts_tests
 		$xml_writer->addXmlNode('PhoronixTestSuite/TestInstallation/Environment/Version', $test_version);
 		$xml_writer->addXmlNode('PhoronixTestSuite/TestInstallation/Environment/CheckSum', $test_checksum);
 		$xml_writer->addXmlNode('PhoronixTestSuite/TestInstallation/Environment/CompilerData', json_encode($compiler_data));
+		$xml_writer->addXmlNode('PhoronixTestSuite/TestInstallation/Environment/InstallFootnote', $install_footnote);
 		$xml_writer->addXmlNode('PhoronixTestSuite/TestInstallation/Environment/SystemIdentifier', $sys_identifier);
 		$xml_writer->addXmlNode('PhoronixTestSuite/TestInstallation/History/InstallTime', $install_time);
 		$xml_writer->addXmlNode('PhoronixTestSuite/TestInstallation/History/InstallTimeLength', $install_time_length);
@@ -267,7 +262,7 @@ class pts_tests
 	}
 	public static function invalid_command_helper($passed_args)
 	{
-		$showed_recent_results = pts_test_run_manager::recently_saved_test_results();
+		$showed_recent_results = self::recently_saved_results();
 
 		if(!empty($passed_args))
 		{
@@ -324,20 +319,96 @@ class pts_tests
 	}
 	public static function recently_saved_results()
 	{
-		$recent_results = array();
-		foreach(pts_file_io::glob(PTS_SAVE_RESULTS_PATH . '*/composite.xml') as $composite)
-		{
-			$recent_results[filemtime($composite)] = basename(dirname($composite));
-		}
+		$recent_results = pts_tests::test_results_by_date();
 
 		if(count($recent_results) > 0)
 		{
-			krsort($recent_results);
-			$recent_results = array_slice($recent_results, 0, 6, true);
+			$recent_results = array_slice($recent_results, 0, 5, true);
+			$res_length = strlen(pts_strings::find_longest_string($recent_results)) + 2;
+			$current_time = time();
+
+			foreach($recent_results as $m_time => &$recent_result)
+			{
+				$days = floor(($current_time - $m_time) / 86400);
+				$recent_result = sprintf('%-' . $res_length . 'ls [%-ls]', $recent_result, ($days == 0 ? 'Today' : pts_strings::days_ago_format_string($days) . ' old'));
+			}
 			echo PHP_EOL . 'Recently Saved Test Results:' . PHP_EOL;
 			echo pts_user_io::display_text_list($recent_results) . PHP_EOL;
 			return true;
 		}
+
+		return false;
+	}
+	public static function test_results_by_date()
+	{
+		$results = array();
+		foreach(pts_file_io::glob(PTS_SAVE_RESULTS_PATH . '*/composite.xml') as $composite)
+		{
+			$results[filemtime($composite)] = basename(dirname($composite));
+		}
+		krsort($results);
+
+		return $results;
+	}
+	public static function search_test_results($query, $search = 'RESULTS')
+	{
+		$matches = array();
+
+		foreach(self::test_results_by_date() as $file)
+		{
+			$result_file = new pts_result_file($file);
+
+			if(($search == 'ALL' || $search == 'INFO') && (stripos($result_file->get_title(), $query) !== false || stripos($result_file->get_description(), $query) !== false))
+			{
+				array_push($matches, $file);
+				continue;
+			}
+
+			if($search == 'ALL' || $search == 'SYSTEM_INFO')
+			{
+				$hw = $result_file->get_system_hardware();
+				$sw = $result_file->get_system_software();
+				$ids = $result_file->get_system_identifiers();
+
+				$matched = false;
+				for($i = 0; $i < count($ids); $i++)
+				{
+					if(stripos($sw[$i], $query) !== false || stripos($ids[$i], $query) !== false || stripos($hw[$i], $query) !== false)
+					{
+						array_push($matches, $file);
+						$matched = true;
+						break;
+					}
+				}
+
+				if($matched)
+				{
+					continue;
+				}
+			}
+
+			if($search == 'ALL' || $search == 'RESULTS')
+			{
+				$matched = false;
+				foreach($result_file->get_result_identifiers() as $result_identifier)
+				{
+					if(stripos($result_identifier, $query) !== false)
+					{
+						array_push($matches, $file);
+						$matched = true;
+						break;
+					}
+				}
+
+				if($matched)
+				{
+					continue;
+				}
+			}
+
+		}
+
+		return $matches;
 	}
 }
 
