@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 	phodevi_gpu.php: The PTS Device Interface object for the graphics processor
 
 	This program is free software; you can redistribute it and/or modify
@@ -343,21 +343,35 @@ class phodevi_gpu extends phodevi_device_interface
 		if(pts_client::executable_in_path('xrandr') && getenv('DISPLAY'))
 		{
 			// Read resolution from xrandr
-			$info = shell_exec('xrandr 2>&1 | grep "*"');
+			// First try reading "current" screen 0 as it should better handle multiple monitors, etc.
+			// e.g. Screen 0: minimum 1 x 1, current 2560 x 1341, maximum 8192 x 8192
+			$info = shell_exec('xrandr 2>&1');
+			$info = substr($info, strpos($info, 'current ') + 8);
+			$info = explode(' x ', trim(substr($info, 0, strpos($info, ','))));
 
-			if(strpos($info, '*') !== false)
+			if(count($info) == 2 && is_numeric($info[0]) && is_numeric($info[1]))
 			{
-				$res = pts_strings::trim_explode('x', $info);
+				$resolution = $info;
+			}
 
-				if(isset($res[1]))
+			if($resolution == false)
+			{
+				$info = shell_exec('xrandr 2>&1 | grep "*"');
+
+				if(strpos($info, '*') !== false)
 				{
-					$res[0] = substr($res[0], strrpos($res[0], ' '));
-					$res[1] = substr($res[1], 0, strpos($res[1], ' '));
-					$res = array_map('trim', $res);
+					$res = pts_strings::trim_explode('x', $info);
 
-					if(is_numeric($res[0]) && is_numeric($res[1]))
+					if(isset($res[1]))
 					{
-						$resolution = array($res[0], $res[1]);
+						$res[0] = substr($res[0], strrpos($res[0], ' '));
+						$res[1] = substr($res[1], 0, strpos($res[1], ' '));
+						$res = array_map('trim', $res);
+
+						if(is_numeric($res[0]) && is_numeric($res[1]))
+						{
+							$resolution = array($res[0], $res[1]);
+						}
 					}
 				}
 			}
@@ -388,7 +402,12 @@ class phodevi_gpu extends phodevi_device_interface
 		}
 		else if(phodevi::is_linux() || phodevi::is_bsd() || phodevi::is_solaris())
 		{
-			if(phodevi::is_linux())
+			if($resolution == false && pts_client::executable_in_path('xrandr'))
+			{
+				$resolution = self::gpu_xrandr_resolution();
+			}
+
+			if($resolution == false && phodevi::is_linux())
 			{
 				// Before calling xrandr first try to get the resolution through KMS path
 				foreach(pts_file_io::glob('/sys/class/drm/card*/*/modes') as $connector_path)
@@ -409,11 +428,6 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 
-			if($resolution == false && pts_client::executable_in_path('xrandr'))
-			{
-				$resolution = self::gpu_xrandr_resolution();
-			}
-
 			if($resolution == false && phodevi::is_nvidia_graphics())
 			{
 				// Way to find resolution through NVIDIA's NV-CONTROL extension
@@ -781,11 +795,17 @@ class phodevi_gpu extends phodevi_device_interface
 		{
 			// GPUDefault3DClockFreqs is the default and does not show under/over-clocking
 			$clock_freqs_3d = pts_strings::comma_explode(phodevi_parser::read_nvidia_extension('GPU3DClockFreqs'));
+			$clock_freqs_current = pts_strings::comma_explode(phodevi_parser::read_nvidia_extension('GPUCurrentClockFreqs'));
 
 			if(is_array($clock_freqs_3d) && isset($clock_freqs_3d[1]))
 			{
 				list($core_freq, $mem_freq) = $clock_freqs_3d;
 			}
+			if(is_array($clock_freqs_current) && isset($clock_freqs_current[1]))
+			{
+				$core_freq = max($core_freq, $clock_freqs_current[0]);
+				$mem_freq = max($mem_freq, $clock_freqs_current[1]);
+			}
 		}
 		else if(phodevi::is_ati_graphics() && phodevi::is_linux()) // ATI GPU
 		{
@@ -833,6 +853,35 @@ class phodevi_gpu extends phodevi_device_interface
 							}
 						}
 					}
+					else if(is_file('/sys/class/drm/card0/device/pstate'))
+					{
+						// pstate is present with Linux 3.13 as the new performance states on Fermi/Kepler
+						$performance_state = pts_file_io::file_get_contents('/sys/class/drm/card0/device/pstate');
+						$performance_level = substr($performance_state, 0, strpos($performance_state, ' *'));
+						$performance_level = substr($performance_level, strrpos($performance_level, ': ') + 2);
+						$performance_level = explode(' ', $performance_level);
+
+						$core_string = array_search('core', $performance_level);
+						if($core_string !== false && isset($performance_level[($core_string + 1)]))
+						{
+							$core_string = str_ireplace('MHz', null, $performance_level[($core_string + 1)]);
+							if(is_numeric($core_string))
+							{
+								$core_freq = $core_string;
+							}
+						}
+
+						$mem_string = array_search('memory', $performance_level);
+						if($mem_string !== false && isset($performance_level[($mem_string + 1)]))
+						{
+							$mem_string = str_ireplace('MHz', null, $performance_level[($mem_string + 1)]);
+							if(is_numeric($mem_string))
+							{
+								$mem_freq = $mem_string;
+							}
+						}
+
+					}
 					break;
 				case 'radeon':
 					if(isset(phodevi::$vfs->radeon_pm_info))
@@ -860,6 +909,33 @@ class phodevi_gpu extends phodevi_device_interface
 								}
 							}
 						}
+						if($core_freq == 0 && ($x = stripos(phodevi::$vfs->radeon_pm_info, 'sclk: ')) != false)
+						{
+							$x = substr(phodevi::$vfs->radeon_pm_info, $x + strlen('sclk: '));
+							$x = substr($x, 0, strpos($x, ' '));
+							if(is_numeric($x) && $x > 100)
+							{
+								if($x > 10000)
+								{
+									$x = $x / 100;
+								}
+								$core_freq = $x;
+							}
+
+							if(($x = stripos(phodevi::$vfs->radeon_pm_info, 'mclk: ')) != false)
+							{
+								$x = substr(phodevi::$vfs->radeon_pm_info, $x + strlen('mclk: '));
+								$x = substr($x, 0, strpos($x, ' '));
+								if(is_numeric($x) && $x > 100)
+								{
+									if($x > 10000)
+									{
+										$x = $x / 100;
+									}
+									$mem_freq = $x;
+								}
+							}
+						}
 					}
 
 					if($core_freq == null)
