@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 	phodevi_system.php: The PTS Device Interface object for the system software
 
 	This program is free software; you can redistribute it and/or modify
@@ -552,12 +552,30 @@ class phodevi_system extends phodevi_device_interface
 						$v = substr($v, ($t + strlen($version) + 1));
 						$v = substr($v, 0, strpos($v, ' '));
 
-						if($v != null && ctype_digit($v))
+						if($v != null && is_numeric($v))
 						{
 							// On development versions the release date is expressed
 							// e.g. gcc version 4.7.0 20120314 (prerelease) (GCC)
 							$version .= ' ' . $v;
 						}
+						else
+						{
+							$v = shell_exec('gcc --version 2>&1');
+							if(($t = strrpos($v, $version)) !== false)
+							{
+								$v = substr($v, $t);
+								$v = substr($v, 0, strpos(str_replace(PHP_EOL, ' ', $v), ' '));
+								if(($t = strpos($v, ')')) !== false)
+								{
+									$v = substr($v, 0, $t);
+								}
+
+								if(pts_strings::is_version($version))
+								{
+									$version = $v;
+								}
+							}
+						}
 					}
 
 					$compilers['gcc'] = 'GCC ' . $version;
@@ -1031,8 +1049,19 @@ class phodevi_system extends phodevi_device_interface
 		$desktop = null;
 		$desktop_environment = null;
 		$desktop_version = null;
+		$desktop_session = pts_client::read_env('DESKTOP_SESSION');
 
-		if(pts_client::is_process_running('gnome-panel'))
+		if(pts_client::is_process_running('gnome-shell'))
+		{
+			// GNOME 3.0 / GNOME Shell
+			$desktop_environment = 'GNOME Shell';
+
+			if(pts_client::executable_in_path('gnome-shell'))
+			{
+				$desktop_version = pts_strings::last_in_string(trim(shell_exec('gnome-shell --version 2> /dev/null')));
+			}
+		}
+		else if(pts_client::is_process_running('gnome-panel') || $desktop_session == 'gnome')
 		{
 			// GNOME
 			$desktop_environment = 'GNOME';
@@ -1046,17 +1075,7 @@ class phodevi_system extends phodevi_device_interface
 				$desktop_version = pts_strings::last_in_string(trim(shell_exec('gnome-session --version 2> /dev/null')));
 			}
 		}
-		else if(pts_client::is_process_running('gnome-shell'))
-		{
-			// GNOME 3.0 / GNOME Shell
-			$desktop_environment = 'GNOME Shell';
-
-			if(pts_client::executable_in_path('gnome-shell'))
-			{
-				$desktop_version = pts_strings::last_in_string(trim(shell_exec('gnome-shell --version 2> /dev/null')));
-			}
-		}
-		else if(pts_client::is_process_running('unity-2d-panel'))
+		else if(pts_client::is_process_running('unity-2d-panel') || $desktop_session == 'ubuntu-2d')
 		{
 			// Canonical / Ubuntu Unity 2D Desktop
 			$desktop_environment = 'Unity 2D';
@@ -1066,7 +1085,7 @@ class phodevi_system extends phodevi_device_interface
 				$desktop_version = pts_strings::last_in_string(trim(shell_exec('unity --version 2> /dev/null')));
 			}
 		}
-		else if(pts_client::is_process_running('unity-panel-service'))
+		else if(pts_client::is_process_running('unity-panel-service') || $desktop_session == 'ubuntu')
 		{
 			// Canonical / Ubuntu Unity Desktop
 			$desktop_environment = 'Unity';
@@ -1076,6 +1095,26 @@ class phodevi_system extends phodevi_device_interface
 				$desktop_version = pts_strings::last_in_string(trim(shell_exec('unity --version 2> /dev/null')));
 			}
 		}
+		else if($desktop_session == 'mate')
+		{
+			$desktop_environment = 'MATE';
+			if(pts_client::executable_in_path('mate-about'))
+			{
+				$desktop_version = pts_strings::last_in_string(trim(shell_exec('mate-about --version 2> /dev/null')));
+			}
+		}
+		else if(($kde5 = pts_client::is_process_running('kded5')))
+		{
+			// KDE 5.x
+			$desktop_environment = 'KDE Frameworks 5';
+			$desktop_version = null; // TODO XXX
+		}
+		else if(($dde = pts_client::is_process_running('dde-desktop')))
+		{
+			// KDE 5.x
+			$desktop_environment = 'Deepin Desktop Environment';
+			$desktop_version = null; // TODO XXX
+		}
 		else if(($kde4 = pts_client::is_process_running('kded4')) || pts_client::is_process_running('kded'))
 		{
 			// KDE 4.x
@@ -1112,7 +1151,7 @@ class phodevi_system extends phodevi_device_interface
 
 			$desktop_environment = $chrome_output;
 		}
-		else if(pts_client::is_process_running('lxsession'))
+		else if(pts_client::is_process_running('lxsession') || $desktop_session == 'lxde')
 		{
 			$lx_output = trim(shell_exec('lxpanel --version'));
 			$version = substr($lx_output, strpos($lx_output, ' ') + 1);
@@ -1120,7 +1159,7 @@ class phodevi_system extends phodevi_device_interface
 			$desktop_environment = 'LXDE';
 			$desktop_version = $version;
 		}
-		else if(pts_client::is_process_running('xfce4-session') || pts_client::is_process_running('xfce-mcs-manager'))
+		else if(pts_client::is_process_running('xfce4-session') || pts_client::is_process_running('xfce-mcs-manager') || $desktop_session == 'xfce')
 		{
 			// Xfce 4.x
 			$desktop_environment = 'Xfce';
@@ -1189,15 +1228,36 @@ class phodevi_system extends phodevi_device_interface
 	}
 	public static function sw_display_server()
 	{
-		$info = null;
+		$display_servers = array();
 
 		if(phodevi::is_windows())
 		{
 			// TODO: determine what to do for Windows support
-			$info = false;
 		}
 		else
 		{
+			if(pts_client::is_process_running('weston'))
+			{
+				$info = 'Wayland Weston';
+				$vinfo = trim(shell_exec('weston --version 2>&1'));
+
+				if(pts_strings::last_in_string($vinfo) && pts_strings::is_version(pts_strings::last_in_string($vinfo)))
+				{
+					$info .= ' ' . pts_strings::last_in_string($vinfo);
+				}
+					array_push($display_servers, $info);
+			}
+			if(pts_client::is_process_running('unity-system-compositor'))
+			{
+				$unity_system_comp = trim(str_replace('unity-system-compositor', null, shell_exec('unity-system-compositor --version 2>&1')));
+
+				if(pts_strings::is_version($unity_system_comp))
+				{
+					array_push($display_servers, 'Unity-System-Compositor ' . $unity_system_comp);
+				}
+
+			}
+
 			if(($x_bin = pts_client::executable_in_path('Xorg')) || ($x_bin = pts_client::executable_in_path('X')))
 			{
 				// Find graphics subsystem version
@@ -1220,27 +1280,23 @@ class phodevi_system extends phodevi_device_interface
 
 				if($info != null)
 				{
-					$info = 'X Server ' . $info;
+					array_push($display_servers, 'X Server ' . $info);
 				}
 			}
-			else if(pts_client::is_process_running('surfaceflinger'))
+			if(pts_client::is_process_running('surfaceflinger'))
 			{
-				$info = 'SurfaceFlinger';
+				array_push($display_servers, 'SurfaceFlinger');
 			}
 
-			if(pts_client::is_process_running('unity-system-compositor'))
+			if(pts_client::is_process_running('gnome-shell-wayland'))
 			{
-				$unity_system_comp = trim(str_replace('unity-system-compositor', null, shell_exec('unity-system-compositor --version 2>&1')));
-
-				if(pts_strings::is_version($unity_system_comp))
-				{
-					$info = 'Unity-System-Compositor ' . $unity_system_comp . ($info != null ? ' + ' . $info : null);
-				}
-
+				array_push($display_servers, 'GNOME Shell Wayland');
 			}
+
+
 		}
 
-		return $info;
+		return implode(' + ', $display_servers);
 	}
 	public static function sw_display_driver($with_version = true)
 	{
@@ -1257,7 +1313,7 @@ class phodevi_system extends phodevi_device_interface
 			{
 				$display_driver = 'fglrx';
 			}
-			else if(phodevi::is_nvidia_graphics())
+			else if(phodevi::is_nvidia_graphics() || is_file('/proc/driver/nvidia/version'))
 			{
 				$display_driver = 'nvidia';
 			}
@@ -1319,9 +1375,11 @@ class phodevi_system extends phodevi_device_interface
 						break;
 					case 'nvidia':
 					case 'NVIDIA':
+					case 'nouveau':
 						// NVIDIA's binary driver usually ends up reporting 1.0.0
 						if(($nvs_value = phodevi_parser::read_nvidia_extension('NvidiaDriverVersion')))
 						{
+							$display_driver = 'NVIDIA';
 							$driver_version = $nvs_value;
 						}
 						else
@@ -1331,6 +1389,7 @@ class phodevi_system extends phodevi_device_interface
 
 							if(($pos = strpos($glxinfo, 'NVIDIA ')) != false)
 							{
+								$display_driver = 'NVIDIA';
 								$driver_version = substr($glxinfo, ($pos + 7));
 							}
 						}
@@ -1474,6 +1533,13 @@ class phodevi_system extends phodevi_device_interface
 				'--libexecdir=',
 				'--infodir=',
 				'--libdir=',
+				'--with-cloog=',
+				'--with-isl=',
+				'--with-java-home=',
+				'--manddir=',
+				'--with-ecj-jar=',
+				'--with-jvm-jar-dir=',
+				'--with-jvm-root-dir=',
 				'--with-sysroot=',
 				'--with-gxx-include-dir=',
 				'--with-system-zlib',
@@ -1566,7 +1632,11 @@ class phodevi_system extends phodevi_device_interface
 	{
 		$dri_driver = false;
 
-		if(is_file('/proc/dri/0/name'))
+		if(is_file('/proc/driver/nvidia/version'))
+		{
+			$dri_driver = 'nvidia';
+		}
+		else if(is_file('/proc/dri/0/name'))
 		{
 			$driver_info = file_get_contents('/proc/dri/0/name');
 			$dri_driver = substr($driver_info, 0, strpos($driver_info, ' '));
