@@ -3,8 +3,9 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2011, Phoronix Media
-	Copyright (C) 2009 - 2011, Michael Larabel
+	Copyright (C) 2009 - 2014, Phoronix Media
+	Copyright (C) 2009 - 2014, Michael Larabel
+	Copyright (C) 2014, Lauri Kasanen
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,9 +24,11 @@
 class gpu_usage implements phodevi_sensor
 {
 	static $probe_ati_overdrive = false;
+	static $probe_radeontop = false;
 	static $probe_radeon_fences = false;
 	static $probe_intel_commands = false;
 	static $probe_nvidia_smi = false;
+	static $probe_nvidia_settings = false;
 
 	public static function get_type()
 	{
@@ -37,7 +40,8 @@ class gpu_usage implements phodevi_sensor
 	}
 	public static function get_unit()
 	{
-		if(self::$probe_ati_overdrive || self::$probe_nvidia_smi)
+		if(self::$probe_ati_overdrive || self::$probe_nvidia_smi || self::$probe_nvidia_settings ||
+			self::$probe_radeontop)
 		{
 			$unit = 'Percent';
 		}
@@ -66,7 +70,17 @@ class gpu_usage implements phodevi_sensor
 		}
 		else if(phodevi::is_mesa_graphics())
 		{
-			if(is_readable('/sys/kernel/debug/dri/0/radeon_fence_info'))
+			if(pts_client::executable_in_path('radeontop'))
+			{
+				$test = self::radeontop_gpu_usage();
+
+				if(is_numeric($test) && $test >= 0)
+				{
+					self::$probe_radeontop = true;
+					return true;
+				}
+			}
+			else if(is_readable('/sys/kernel/debug/dri/0/radeon_fence_info'))
 			{
 				$fence_speed = self::radeon_fence_speed();
 
@@ -88,7 +102,14 @@ class gpu_usage implements phodevi_sensor
 		}
 		else if(phodevi::is_nvidia_graphics())
 		{
-			if(pts_client::executable_in_path('nvidia-smi'))
+			$util = self::read_nvidia_settings_gpu_utilization();
+
+			if($util !== false)
+			{
+				self::$probe_nvidia_settings = true;
+				return true;
+			}
+			else if(pts_client::executable_in_path('nvidia-smi'))
 			{
 				$usage = self::nvidia_core_usage();
 
@@ -108,10 +129,18 @@ class gpu_usage implements phodevi_sensor
 		{
 			return self::ati_overdrive_core_usage();
 		}
+		else if(self::$probe_nvidia_settings)
+		{
+			return self::read_nvidia_settings_gpu_utilization();
+		}
 		else if(self::$probe_nvidia_smi)
 		{
 			return self::nvidia_core_usage();
 		}
+		else if(self::$probe_radeontop)
+		{
+			return self::radeontop_gpu_usage();
+		}
 		else if(self::$probe_radeon_fences)
 		{
 			return self::radeon_fence_speed();
@@ -121,6 +150,30 @@ class gpu_usage implements phodevi_sensor
 			return self::intel_command_speed();
 		}
 	}
+	public static function read_nvidia_settings_gpu_utilization()
+	{
+		$util = phodevi_parser::read_nvidia_extension('GPUUtilization');
+
+		if(is_numeric($util) && $util >= 0 && $util <= 100)
+		{
+			return $util;
+		}
+		else
+		{
+			if(($x = stripos($util, 'graphics=')) !== false)
+			{
+				$util = substr($util, ($x + 9));
+				$util = substr($util, 0, strpos($util, ','));
+
+				if(is_numeric($util) && $util >= 0 && $util <= 100)
+				{
+					return $util;
+				}
+			}
+		}
+
+		return false;
+	}
 	public static function ati_overdrive_core_usage()
 	{
 		return phodevi_linux_parser::read_ati_overdrive('GPUload');
@@ -190,6 +243,19 @@ class gpu_usage implements phodevi_sensor
 
 		return $second_read - $first_read;
 	}
+	public static function radeontop_gpu_usage()
+	{
+		$out = shell_exec('radeontop -d - -l 1');
+
+		$pos = strpos($out, 'gpu');
+		if ($pos === false)
+			return -1;
+
+		$out = substr($out, $pos + 4);
+		$out = trim(substr($out, 0, strpos($out, '%')));
+
+		return $out;
+	}
 }
 
 ?>
