@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2010, Phoronix Media
-	Copyright (C) 2009 - 2010, Michael Larabel
+	Copyright (C) 2009 - 2011, Phoronix Media
+	Copyright (C) 2009 - 2011, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,15 +24,15 @@ class sys_v12 implements phodevi_sensor
 {
 	public static function get_type()
 	{
-		return "sys";
+		return 'sys';
 	}
 	public static function get_sensor()
 	{
-		return "v12-voltage";
+		return 'v12-voltage';
 	}
 	public static function get_unit()
 	{
-		return "Volts";
+		return 'Volts';
 	}
 	public static function support_check()
 	{
@@ -41,9 +41,9 @@ class sys_v12 implements phodevi_sensor
 	}
 	public static function read_sensor()
 	{
-		if(IS_LINUX)
+		if(phodevi::is_linux())
 		{
-			$sensor = phodevi_linux_parser::read_sensors(array("V12", "+12V"));
+			$sensor = phodevi_linux_parser::read_sensors(array('V12', '+12V'));
 		}
 		else
 		{
