@@ -39,7 +39,8 @@ class pts_exdep_platform_parser
 			$distro_package = $xml_parser->getXMLArrayValues('PhoronixTestSuite/ExternalDependencies/Package/PackageName');
 			$file_check = $xml_parser->getXMLArrayValues('PhoronixTestSuite/ExternalDependencies/Package/FileCheck');
 			$arch_specific = $xml_parser->getXMLArrayValues('PhoronixTestSuite/ExternalDependencies/Package/ArchitectureSpecific');
-			$kernel_architecture = phodevi::read_property('system', 'kernel-architecture');
+			$os_version_specific = $xml_parser->getXMLArrayValues('PhoronixTestSuite/ExternalDependencies/Package/VersionSpecific');
+			$os_version = phodevi::read_property('system', 'os-version');
 
 			foreach(array_keys($generic_package) as $i)
 			{
@@ -47,6 +48,11 @@ class pts_exdep_platform_parser
 				{
 					continue;
 				}
+				$os_version_compliant = empty($os_version_specific[$i]) || in_array($os_version, pts_strings::comma_explode($os_version_specific[$i]));
+				if($os_version_compliant == false)
+				{
+					continue;
+				}
 
 				$this->struct['external-dependencies']['packages'][$generic_package[$i]] = $this->get_package_format($distro_package[$i], $file_check[$i], $arch_specific[$i]);
 			}
