@@ -57,7 +57,7 @@ class pts_network
 		$stream_context = pts_network::stream_context_create($http_parameters);
 		$opened_url = fopen($url, 'rb', false, $stream_context);
 		$response = $opened_url ? stream_get_contents($opened_url) : false;
-
+		// var_dump($url); var_dump($to_post_data);
 		return $response;
 	}
 	public static function download_file($download, $to)
@@ -272,7 +272,7 @@ class pts_network
 			//echo PHP_EOL . 'Network Communication Is Disabled For Your User Configuration.' . PHP_EOL . PHP_EOL;
 			self::$disable_network_support = true;
 		}
-		else
+		else if(!PTS_IS_WEB_CLIENT)
 		{
 			$server_response = pts_network::http_get_contents('http://www.phoronix-test-suite.com/PTS', false, false);
 
@@ -297,6 +297,30 @@ class pts_network
 			echo PHP_EOL . 'The file_uploads option in your PHP configuration must be enabled for network support.' . PHP_EOL . PHP_EOL;
 		}
 	}
+	public static function get_local_ip()
+	{
+		$local_ip = false;
+
+		if(($ifconfig = pts_client::executable_in_path('ifconfig')))
+		{
+			$ifconfig = shell_exec($ifconfig . ' 2>&1');
+			$offset = 0;
+			while(($ipv4_pos = strpos($ifconfig, 'inet addr:', $offset)) !== false)
+			{
+				$ipv4 = substr($ifconfig, $ipv4_pos + strlen('inet addr:'));
+				$ipv4 = substr($ipv4, 0, strpos($ipv4, ' '));
+				$local_ip = $ipv4;
+
+				if($local_ip != '127.0.0.1' && $local_ip != null)
+				{
+					break;
+				}
+				$offset = $ipv4_pos + 1;
+			}
+		}
+
+		return $local_ip;
+	}
 }
 
 ?>
