@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2012, Phoronix Media
-	Copyright (C) 2010 - 2012, Michael Larabel
+	Copyright (C) 2010 - 2014, Phoronix Media
+	Copyright (C) 2010 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 
 class pts_openbenchmarking
 {
+	protected static $openbenchmarking_index_refreshed = false;
+
 	public static function stats_hardware_list()
 	{
 		return array(
@@ -62,7 +64,14 @@ class pts_openbenchmarking
 
 		if(strlen($gsid) == 9)
 		{
-			if(ctype_upper(substr($gsid, 0, 6)) && ctype_digit(substr($gsid, 6, 3)))
+			if(function_exists('ctype_digit'))
+			{
+				if(ctype_upper(substr($gsid, 0, 6)) && ctype_digit(substr($gsid, 6, 3)))
+				{
+					$gsid_valid = true;
+				}
+			}
+			else if(substr($gsid, 0, 6) == strtoupper(substr($gsid, 0, 6)) && is_numeric(substr($gsid, 6, 3)))
 			{
 				$gsid_valid = true;
 			}
@@ -76,7 +85,7 @@ class pts_openbenchmarking
 
 		if(strlen($gside) == 12)
 		{
-			if(ctype_upper(substr($gside, 0, 10)) && ctype_digit(substr($gside, 10, 2)))
+			if(substr($gside, 0, 10) == strtoupper(substr($gside, 0, 10)) && is_numeric(substr($gside, 10, 2)))
 			{
 				$gside_valid = true;
 			}
@@ -90,7 +99,7 @@ class pts_openbenchmarking
 
 		if(strlen($gsidp) == 10)
 		{
-			if(ctype_upper(substr($gsidp, 0, 9)) &&	ctype_digit(substr($gsidp, 9, 1)))
+			if(substr($gsidp, 0, 9) == strtoupper(substr($gsidp, 0, 9)) && is_numeric(substr($gsidp, 9, 1)))
 			{
 				$gsidp_valid = true;
 			}
@@ -226,7 +235,9 @@ class pts_openbenchmarking
 			// Use HTTPS if OpenSSL is available as a check to see if HTTPS can be handled
 			// OpenSSL seems to have problems on OpenIndiana at least, TODO: investigate
 			// Using a proxy seems to have problems for HTTPS
-			$host = ((extension_loaded('openssl') && getenv('NO_OPENSSL') == false && php_uname('s') == 'Linux' && (!PTS_IS_CLIENT || !pts_network::is_proxy_setup())) ? 'https://' : 'http://') . 'openbenchmarking.org/';
+			// TODO XXX
+			//$host = ((extension_loaded('openssl') && getenv('NO_OPENSSL') == false && php_uname('s') == 'Linux' && (!PTS_IS_CLIENT || !pts_network::is_proxy_setup())) ? 'https://' : 'http://') . 'openbenchmarking.org/';
+			$host = 'http://openbenchmarking.org/';
 		}
 
 		return $host;
@@ -293,9 +304,15 @@ class pts_openbenchmarking
 					// The index is new enough
 					continue;
 				}
-			}
 
-			$server_index = pts_openbenchmarking::make_openbenchmarking_request('repo_index', array('repo' => $repo_name));
+				$server_index = pts_openbenchmarking::make_openbenchmarking_request('repo_index', array('repo' => $repo_name));
+				self::$openbenchmarking_index_refreshed = true;
+			}
+			else
+			{
+				$server_index = pts_openbenchmarking::make_openbenchmarking_request('repo_index', array('repo' => $repo_name));
+				self::$openbenchmarking_index_refreshed = true;
+			}
 
 			if(json_decode($server_index) != false)
 			{
@@ -318,6 +335,10 @@ class pts_openbenchmarking
 			}
 		}
 	}
+	public static function openbenchmarking_has_refreshed()
+	{
+		return self::$openbenchmarking_index_refreshed;
+	}
 	public static function linked_repositories()
 	{
 		$repos = array('local', 'pts');
@@ -364,15 +385,30 @@ class pts_openbenchmarking
 		{
 			return true;
 		}
-
 		$file = PTS_OPENBENCHMARKING_SCRATCH_PATH . $qualified_identifier . '.zip';
+		if(!is_file($file))
+		{
+			$cache_locations = array('/var/cache/phoronix-test-suite/openbenchmarking.org/');
 
-		$hash_json = pts_openbenchmarking::make_openbenchmarking_request('test_hash', array('i' => $qualified_identifier));
-		$hash_json = json_decode($hash_json, true);
-		$hash_check = isset($hash_json['openbenchmarking']['test']['hash']) ? $hash_json['openbenchmarking']['test']['hash'] : null;  // should also check for ['openbenchmarking']['test']['error'] problems
+			foreach($cache_locations as $cache_location)
+			{
+				// Assuming if file is present that the SHA1 checksum is fine
+				// otherwise add: && ($hash_check == null || sha1_file($cache_location . $qualified_identifier . '.zip') == $hash_check)
+				if(is_file($cache_location . $qualified_identifier . '.zip'))
+				{
+					copy($cache_location . $qualified_identifier . '.zip', $file);
+					break;
+				}
+			}
+		}
 
 		if(!is_file($file))
 		{
+			// TODO cache this somewhere
+			$hash_json = pts_openbenchmarking::make_openbenchmarking_request('test_hash', array('i' => $qualified_identifier));
+			$hash_json = json_decode($hash_json, true);
+			$hash_check = isset($hash_json['openbenchmarking']['test']['hash']) ? $hash_json['openbenchmarking']['test']['hash'] : null;  // should also check for ['openbenchmarking']['test']['error'] problems
+
 			$test_profile = pts_openbenchmarking::make_openbenchmarking_request('download_test', array('i' => $qualified_identifier));
 
 			if($test_profile != null && ($hash_check == null || $hash_check == sha1($test_profile)))
@@ -381,10 +417,6 @@ class pts_openbenchmarking
 				file_put_contents($file, $test_profile);
 				$hash_check = null;
 			}
-			else if(is_file('/var/cache/phoronix-test-suite/openbenchmarking.org/' . $qualified_identifier . '.zip') && ($hash_check == null || sha1_file('/var/cache/phoronix-test-suite/openbenchmarking.org/' . $qualified_identifier . '.zip') == $hash_check))
-			{
-				copy('/var/cache/phoronix-test-suite/openbenchmarking.org/' . $qualified_identifier . '.zip', $file);
-			}
 			else if(PTS_IS_CLIENT && $test_profile === false)
 			{
 				trigger_error('Network support is needed to obtain ' . $qualified_identifier . ' data.' . PHP_EOL, E_USER_ERROR);
@@ -392,7 +424,7 @@ class pts_openbenchmarking
 			}
 		}
 
-		if(!is_file(PTS_TEST_PROFILE_PATH . $qualified_identifier . '/test-definition.xml') && is_file($file) && ($hash_check == null || sha1_file($file) == $hash_check))
+		if(!is_file(PTS_TEST_PROFILE_PATH . $qualified_identifier . '/test-definition.xml') && is_file($file))
 		{
 			// extract it
 			pts_file_io::mkdir(PTS_TEST_PROFILE_PATH . dirname($qualified_identifier));
@@ -427,6 +459,7 @@ class pts_openbenchmarking
 				}
 			}
 		}
+		$available_tests = array_unique($available_tests);
 
 		return $available_tests;
 	}
@@ -679,9 +712,9 @@ class pts_openbenchmarking
 
 		return false;
 	}
-	public static function upload_test_result(&$object)
+	public static function upload_test_result(&$object, $return_json_data = false)
 	{
-		return pts_openbenchmarking_client::upload_test_result($object);
+		return pts_openbenchmarking_client::upload_test_result($object, $return_json_data);
 	}
 }
 
