@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -192,7 +192,7 @@ class pts_test_profile extends pts_test_profile_parser
 			// set SKIP_TEST_SUPPORT_CHECKS=1 environment variable for debugging purposes to run tests on unsupported platforms
 			return true;
 		}
-		if($this->is_test_architecture_supported() == false)
+		else if($this->is_test_architecture_supported() == false)
 		{
 			PTS_IS_CLIENT && $report_warnings && pts_client::$display->test_run_error($this->get_identifier() . ' is not supported on this architecture: ' . phodevi::read_property('system', 'kernel-architecture'));
 			$test_supported = false;
@@ -210,9 +210,20 @@ class pts_test_profile extends pts_test_profile_parser
 		else if(PTS_IS_CLIENT && ($custom_support_check = $this->custom_test_support_check()) !== true)
 		{
 			// A custom-self-generated error occurred, see code comments in custom_test_support_check()
-			PTS_IS_CLIENT && $report_warnings && pts_client::$display->test_run_error($this->get_identifier() . ': ' . $custom_support_check);
+			PTS_IS_CLIENT && $report_warnings && is_callable(array(pts_client::$display, 'test_run_error')) && pts_client::$display->test_run_error($this->get_identifier() . ': ' . $custom_support_check);
 			$test_supported = false;
 		}
+		else if(PTS_IS_CLIENT)
+		{
+			foreach($this->extended_test_profiles() as $extension)
+			{
+				if($extension->is_supported($report_warnings) == false)
+				{
+					$test_supported = false;
+					break;
+				}
+			}
+		}
 
 		return $test_supported;
 	}
@@ -376,6 +387,19 @@ class pts_test_profile extends pts_test_profile_parser
 		// || $this->test_installation->get_installed_system_identifier() != phodevi::system_id_string()
 		return $this->test_installation == false || $this->get_test_profile_version() != $this->test_installation->get_installed_version() || $this->get_installer_checksum() != $this->test_installation->get_installed_checksum() || (pts_c::$test_flags & pts_c::force_install);
 	}
+	public function to_json()
+	{
+		$file = $this->xml_parser->getFileLocation();
+
+		if(is_file($file))
+		{
+			$file = file_get_contents($file);
+			$file = str_replace(array("\n", "\r", "\t"), '', $file);
+			$file = trim(str_replace('"', "'", $file));
+			$simple_xml = simplexml_load_string($file);
+			return json_encode($simple_xml);
+		}
+	}
 }
 
 ?>
