@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 	phoronix-test-suite.php: The main code for initalizing the Phoronix Test Suite
 
 	This program is free software; you can redistribute it and/or modify
@@ -30,12 +30,47 @@ define('PTS_PATH', dirname(dirname(__FILE__)) . '/');
 // SILENT = Load all normal pts-core files, but don't run client code
 if(!defined('PTS_MODE'))
 {
-	define('PTS_MODE', in_array(($m = getenv('PTS_MODE')), array('CLIENT', 'LIB', 'SILENT')) ? $m : 'CLIENT');
+	define('PTS_MODE', in_array(($m = getenv('PTS_MODE')), array('CLIENT', 'LIB', 'WEB_CLIENT', 'SILENT')) ? $m : 'CLIENT');
 }
 
 // Any PHP default memory limit should be fine for PTS, until you run image quality comparison tests that begins to consume memory
 ini_set('memory_limit', '256M');
 
+if(getenv('PTS_MODE') == 'CLIENT' && ini_get('open_basedir') != false)
+{
+	$passes = true;
+	$open_basedir = ini_get('open_basedir');
+
+	if($open_basedir != false)
+	{
+		$is_in_allowed_dir = false;
+		foreach(explode(':', $open_basedir) as $allowed_dir)
+		{
+			if(strpos(PTS_PATH, $allowed_dir) === 0)
+			{
+				$is_in_allowed_dir = true;
+				break;
+			}
+		}
+
+		if($is_in_allowed_dir == false)
+		{
+			$passes = false;
+		}
+	}
+
+
+	if($passes == false)
+	{
+		echo PHP_EOL . 'ERROR: The php.ini configuration open_basedir directive is preventing ' . PTS_PATH . ' from loading.' . PHP_EOL;
+		return false;
+	}
+	else
+	{
+		echo PHP_EOL . 'NOTICE: The php.ini configuration is using the "open_basedir" directive, which may prevent some parts of the Phoronix Test Suite from working. See the Phoronix Test Suite documentation for more details and to disable this setting.' . PHP_EOL;
+	}
+}
+
 require(PTS_PATH . 'pts-core/pts-core.php');
 
 if(!PTS_IS_CLIENT)
@@ -44,49 +79,9 @@ if(!PTS_IS_CLIENT)
 	return;
 }
 
-pts_define('IS_PTS_WEB_INTERFACE', php_sapi_name() == 'cli-server');
-
-if(IS_PTS_WEB_INTERFACE == 'cli-server')
-{
-	$argv = array();
-	$argv[1] = 'webui';
-	$argc = count($argv);
-}
-
 // Default to C locale
 setlocale(LC_ALL, 'C');
 
-if(ini_get('date.timezone') == null)
-{
-	$tz = null;
-
-	// timezone_name_from_abbr was added in PHP 5.1.3. pre-5.2 really isn't supported by PTS, but don't at least error out here but let it get to proper checks...
-	if(is_executable('/bin/date') && function_exists('timezone_name_from_abbr'))
-	{
-		$tz = timezone_name_from_abbr(trim(shell_exec('date +%Z 2> /dev/null')));
-	}
-
-	if($tz == null || !in_array($tz, timezone_identifiers_list()))
-	{
-		$tz = 'UTC';
-	}
-
-	date_default_timezone_set($tz);
-}
-
-if(ini_get('open_basedir') != false)
-{
-	if(pts_client::open_basedir_check() == false)
-	{
-		echo PHP_EOL . 'ERROR: The php.ini configuration open_basedir directive is preventing ' . PTS_PATH . ' from loading.' . PHP_EOL;
-		return false;
-	}
-	else
-	{
-		trigger_error('The php.ini configuration is using the "open_basedir" directive, which may prevent some parts of the Phoronix Test Suite from working. See the Phoronix Test Suite documentation for more details and to disable this setting.', E_USER_WARNING);
-	}
-}
-
 // Needed for shutdown functions
 // declare(ticks = 1);
 
@@ -94,7 +89,7 @@ $sent_command = strtolower(str_replace('-', '_', (isset($argv[1]) ? $argv[1] : n
 $quick_start_options = array('dump_possible_options');
 pts_define('QUICK_START', in_array($sent_command, $quick_start_options));
 
-if(QUICK_START == false && IS_PTS_WEB_INTERFACE == false)
+if(QUICK_START == false)
 {
 	pts_client::program_requirement_checks(true);
 }
@@ -138,16 +133,18 @@ if(is_file(PTS_PATH . 'pts-core/commands/' . $sent_command . '.php') == false)
 	}
 }
 
-pts_define('PTS_USER_LOCK', PTS_USER_PATH . 'run_lock');
 
-if(QUICK_START == false && IS_PTS_WEB_INTERFACE == false)
+pts_define('PTS_USER_LOCK', function_exists('posix_getpid') ? PTS_USER_PATH . 'run-lock-' . posix_getpid() : tempnam(PTS_USER_PATH, 'run-lock-'));
+
+if(QUICK_START == false)
 {
 	if(pts_client::create_lock(PTS_USER_LOCK) == false)
 	{
-		pts_client::$display->generic_warning('It appears that the Phoronix Test Suite is already running.' . PHP_EOL . 'For proper results, only run one instance at a time.');
+		//trigger_error('It appears that the Phoronix Test Suite is already running.' . PHP_EOL . 'For proper results, only run one instance at a time.', E_USER_WARNING);
 	}
 
 	register_shutdown_function(array('pts_client', 'process_shutdown_tasks'));
+	//pcntl_signal(SIGTERM, array('pts_client', 'exit_client'));
 
 	if(pts_client::read_env('PTS_IGNORE_MODULES') == false)
 	{
@@ -161,7 +158,7 @@ for($i = 2; $i < $argc && isset($argv[$i]); $i++)
 	array_push($pass_args, $argv[$i]);
 }
 
-if(QUICK_START == false && IS_PTS_WEB_INTERFACE == false)
+if(QUICK_START == false)
 {
 	pts_client::user_agreement_check($sent_command);
 	pts_client::user_hardware_software_reporting();
