@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2013, Phoronix Media
-	Copyright (C) 2008 - 2013, Michael Larabel
+	Copyright (C) 2008 - 2014, Phoronix Media
+	Copyright (C) 2008 - 2014, Michael Larabel
 	pts-core.php: To boot-strap the Phoronix Test Suite start-up
 
 	This program is free software; you can redistribute it and/or modify
@@ -50,7 +50,7 @@ function pts_define_directories()
 
 	if(PTS_IS_CLIENT)
 	{
-		pts_define('PTS_USER_PATH', pts_client::user_home_directory() . '.phoronix-test-suite/');
+		pts_define('PTS_USER_PATH', pts_client::user_home_directory() . '.phoronix-test-suite' . DIRECTORY_SEPARATOR);
 		pts_define('PTS_CORE_STORAGE', PTS_USER_PATH . 'core.pt2so');
 		pts_define('PTS_TEMP_STORAGE', PTS_USER_PATH . 'temp.pt2so');
 		pts_define('PTS_MODULE_LOCAL_PATH', PTS_USER_PATH . 'modules/');
@@ -93,6 +93,7 @@ function pts_needed_extensions()
 		array(0, extension_loaded('openssl'), 'OpenSSL', 'PHP OpenSSL support is recommended to support HTTPS traffic.'),
 		array(0, extension_loaded('gd'), 'GD', 'The PHP GD library is recommended for improved graph rendering.'),
 		array(0, extension_loaded('zlib'), 'Zlib', 'The PHP Zlib extension can be used for greater file compression.'),
+		array(0, extension_loaded('sqlite3'), 'SQLite3', 'The PHP SQLite3 extension is required when running a Phoromatic server.'),
 		array(0, function_exists('pcntl_fork'), 'PCNTL', 'PHP PCNTL is highly recommended as it is required by some tests.'),
 		array(0, function_exists('posix_getpwuid'), 'POSIX', 'PHP POSIX support is highly recommended.'),
 		array(0, function_exists('curl_init'), 'CURL', 'PHP CURL is recommended for an enhanced download experience.'),
@@ -136,10 +137,11 @@ function pts_version_codenames()
 		);
 }
 
-pts_define('PTS_VERSION', '4.8.3');
-pts_define('PTS_CORE_VERSION', 4830);
-pts_define('PTS_CODENAME', 'SOKNDAL');
-pts_define('PTS_IS_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'CLIENT'));
+pts_define('PTS_VERSION', '5.2.1');
+pts_define('PTS_CORE_VERSION', 5210);
+pts_define('PTS_CODENAME', 'KHANINO');
+pts_define('PTS_IS_CLIENT', (defined('PTS_MODE') && strstr(PTS_MODE, 'CLIENT') !== false));
+pts_define('PTS_IS_WEB_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'WEB_CLIENT'));
 pts_define('PTS_IS_DEV_BUILD', (substr(PTS_VERSION, -2, 1) == 'm'));
 
 if(!defined('PTS_PATH'))
@@ -189,5 +191,22 @@ if(PTS_IS_CLIENT || defined('PTS_AUTO_LOAD_OBJECTS'))
 		}
 	}
 }
+if(PTS_IS_CLIENT && ini_get('date.timezone') == null)
+{
+	$tz = null;
+
+	// timezone_name_from_abbr was added in PHP 5.1.3. pre-5.2 really isn't supported by PTS, but don't at least error out here but let it get to proper checks...
+	if(is_executable('/bin/date') && function_exists('timezone_name_from_abbr'))
+	{
+		$tz = timezone_name_from_abbr(trim(shell_exec('date +%Z 2> /dev/null')));
+	}
+
+	if($tz == null || !in_array($tz, timezone_identifiers_list()))
+	{
+		$tz = 'UTC';
+	}
+
+	date_default_timezone_set($tz);
+}
 
 ?>
